(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11843,        363]*)
(*NotebookOutlinePosition[     37666,       1307]*)
(*  CellTagsIndexPosition[     37622,       1303]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Alberi", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["MakeNode[x,y,...]",
    FontWeight->"Bold"],
  "\nCrea nuovi nodi associati ai simboli x,y,... \n",
  StyleBox["ClearNode[x,y,...]",
    FontWeight->"Bold"],
  "\nElimina i nodi x,y,...\n",
  StyleBox["Nodes",
    FontWeight->"Bold"],
  "\nLista dei nodi definiti mediante MakeNode.\n",
  StyleBox["NodeQ[x]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se x e' un nodo."
}], "Text"],

Cell["\<\
ClearAll[Nodes,NodeQ,MakeNode,ClearNode,Parent,Children];

Nodes = {};

NodeQ[x_] := MemberQ[Nodes,x]

MakeNode[x_] := 
  If[Not[Head[x] === Symbol],
     Message[Nodes::symb,x]; HoldForm[MakeNode[x]],
     If[NodeQ[x],
        Message[Nodes::make,x]; HoldForm[MakeNode[x]],
        Nodes = Append[Nodes,x]; 
        ClearAll[x]; 
        x /: Children[x] = {}; x /: Parent[x] = {}; Nodes]]
     
MakeNode[x__] := (Map[MakeNode,{x}]; Nodes)

ClearNode[x_] :=
  If[Not[NodeQ[x]],
     Message[Nodes::node,x]; HoldForm[ClearNode[x]],
     Nodes = DeleteCases[Nodes,x];
     With[{p = Parent[x],c = Children[x]},
       If[p =!= {},p /: Children[p] = DeleteCases[Children[p],x]];
       Map[(# /: Parent[#] = {})&,c]];
     ClearAll[x]; Nodes]
     
ClearNode[x__] := (Map[ClearNode,{x}]; Nodes)
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Parent[x]",
    FontWeight->"Bold"],
  "\nNodo padre del nodo x.\n",
  StyleBox["Children[x]",
    FontWeight->"Bold"],
  "\nLista dei nodi figli del nodo x.",
  StyleBox["\nRootQ[x]",
    FontWeight->"Bold"],
  "\nFunzione booleana vera se x e' una radice (nodo senza genitore).\n",
  StyleBox["LeafQ[x]",
    FontWeight->"Bold"],
  "\nEspresisone booleana vera se x e' una foglia (nodo senza figli)."
}], "Text"],

Cell["\<\
ClearAll[RootQ,LeafQ];

Parent[x_] := (Message[Nodes::node,x]; HoldForm[Parent[x]])
Children[x_] := (Message[Nodes::node,x]; HoldForm[Children[x]])

RootQ[x_] := Parent[x] === {}
LeafQ[x_] := Children[x] === {}
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["SetParent[x,y]",
    FontWeight->"Bold"],
  "\nPone il genitore di x uguale a y.\n",
  StyleBox["ClearParent[x]\n",
    FontWeight->"Bold"],
  "Pone il genitore di x uguale a {}.\n",
  StyleBox["SetChildren[x,{y,...}]",
    FontWeight->"Bold"],
  "\nPone la lista dei figli di x uguale a {y,...}.\n",
  StyleBox["ClearChildren[x]\n",
    FontWeight->"Bold"],
  "Pone la lista dei figli di x uguale a {}.\n",
  StyleBox["AddChildren[x,{y,...}]",
    FontWeight->"Bold"],
  "\nAggiunge alla lista dei figli di x i nodi y,...\n",
  StyleBox["RemoveChildren[x,{y,...}]",
    FontWeight->"Bold"],
  "\nRimuove dalla lista dei figli di x i nodi y,..."
}], "Text"],

Cell["\<\
ClearAll[SetParent,ClearParent,SetChildren,ClearChildren,
         AddChildren,RemoveChildren];

SetParent[x_,y_] :=
  If[Not[NodeQ[x]],
     Message[Nodes::node,x]; HoldForm[SetParent[x,y]], 
   If[Not[NodeQ[y]], 
      Message[Nodes::node,y]; HoldForm[SetParent[x,y]],
    If[Parent[x] =!= {},
       With[{p = Parent[x]},
         p /: Children[p] = DeleteCases[Children[p],x]; 
         y /: Children[y] = Append[Children[y],x]]];
         x /: Parent[x] = y]]

ClearParent[x_] := 
  If[Not[NodeQ[x]],
     Message[Nodes::node,x]; HoldForm[ClearParent[x]], 
   If[Parent[x] =!= {},
      With[{p = Parent[x]},
        p /: Children[p] = DeleteCases[Children[p],x]]]; 
        x /: Parent[x] = {}]

SetChildren[x_,l_List] := 
  If[Not[NodeQ[x]],
     Message[Nodes::node,x]; HoldForm[SetChildren[x,l]], 
   If[Not[Apply[And,Map[NodeQ,l]]],
      Message[Nodes::nodes,l]; HoldForm[SetChildren[x,l]], 
      Map[RemoveChildren[1][x,#]&,Children[x]]; 
      Map[AddChildren[1][x,#]&,l]; Children[x]]]

ClearChildren[x_] := 
  If[Not[NodeQ[x]],
     Message[Nodes::node,x]; HoldForm[ClearChildren[x]], 
     Map[RemoveChildren[1][x,#]&,Children[x]]; {}]

AddChildren[x_,l_List] := 
  If[Not[NodeQ[x]],
     Message[Nodes::node,x]; HoldForm[AddChildren[x,l]], 
   If[Not[Apply[And,Map[NodeQ,l]]],
      Message[Nodes::nodes,l]; HoldForm[AddChildren[x,l]], 
      Map[AddChildren[1][x,#]&,l]; Children[x]]]
  
AddChildren[1][x_,y_] := 
  If[Not[RootQ[y]],Message[Nodes::add,y], 
   If[TreeRoot[x] === y,Message[Nodes::loop,y,x], 
      x /: Children[x] = Append[Children[x],y];
      y /: Parent[y] = x;]]

RemoveChildren[x_,l_List] :=
  If[Not[NodeQ[x]],
     Message[Nodes::node,x]; HoldForm[RemoveChildren[x,l]], 
   If[Not[Apply[And,Map[NodeQ,l]]],
      Message[Nodes::nodes,l]; HoldForm[RemoveChildren[x,l]], 
      Map[RemoveChildren[1][x,#]&,l]; Children[x]]]

RemoveChildren[1][x_,y_] := 
  If[Not[MemberQ[Children[x],y]],Message[Nodes::child,y,x], 
     x /: Children[x] = DeleteCases[Children[x],y]; 
     y /: Parent[y] = {};]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["InsertNode[x,y,{z,...}]",
    FontWeight->"Bold"],
  "\nInserisce il nodo x tra y e i suoi figli z,... \n",
  StyleBox["CancelNode[x]",
    FontWeight->"Bold"],
  "\nElimina il nodo x aggiungendo i suoi figli ai figli del suo nodo padre."
}], "Text"],

Cell["\<\
ClearAll[InsertNode,CancelNode];

InsertNode[x_,y_,l_List] := 
  If[Not[NodeQ[x]],
     Message[Nodes::node,x]; HoldForm[InsertNode[x,y,l]], 
   If[Not[RootQ[x] && LeafQ[x]],
      Message[Nodes::insert,x]; HoldForm[InsertNode[x,y,l]], 
    If[Not[NodeQ[y]],
       Message[Nodes::node,y]; HoldForm[InsertNode[x,y,l]], 
     If[Not[Apply[And,Map[MemberQ[Children[y],#]&,l]]],
        Message[Nodes::children,l,y]; HoldForm[InsertNode[x,y,l]], 
        y /: Children[y] = DeleteCases[Children[y] /. First[l] :> x,
                                       Apply[Alternatives,Rest[l]]]; 
        x /: Parent[x] = y; x /: Children[x] = l; x]]]]

CancelNode[x_] := 
  If[Not[NodeQ[x]], 
     Message[Nodes::node,x]; HoldForm[CancelNode[x]],
   If[RootQ[x], 
      Message[Nodes::cancel,x]; HoldForm[CancelNode[x]],
      With[{p = Parent[x]},
        p /: Children[p] = Flatten[Children[p] /. x :> Children[x]];
        x /: Children[x] = {}; x /: Parent[x] = {}; x]]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["TreeRoot[x]",
    FontWeight->"Bold"],
  "\nRadice dell'albero contenente il nodo x.\n",
  StyleBox["TreePath[x]",
    FontWeight->"Bold"],
  "\nLista dei nodi che si attraversano a partire dalla radice dell'albero \
contenente x per arrivare fino ad x stesso."
}], "Text"],

Cell["\<\
ClearAll[TreePath,TreeRoot];

TreePath[x_?NodeQ] := If[RootQ[x],{x},Append[TreePath[Parent[x]],x]]
     
TreeRoot[x_?NodeQ] := If[RootQ[x],x,TreeRoot[Parent[x]]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["TreeNodes[x]",
    FontWeight->"Bold"],
  "\nLista dei nodi presenti nell'albero generato dal nodo x.\n",
  StyleBox["TreeNodes[x,n]",
    FontWeight->"Bold"],
  "\nLista dei nodi presenti nell'albero generato dal nodo x, fino al grado \
di discendenza n.\n",
  StyleBox["TreeLeaves[x]\n",
    FontWeight->"Bold"],
  "Lista delle foglie presenti nell'albero generato dal nodo x."
}], "Text"],

Cell[TextData[{
  "ClearAll[TreeNodes,TreeLeaves];\n\n",
  StyleBox["TreeNodes[x_?NodeQ,n_Integer:-1] := \n  If[LeafQ[x] || n == 0,\n  \
   {x},\n     Prepend[Apply[Join,Map[TreeNodes[#,n-1]&,Children[x]]],x]]\n\n\
TreeLeaves[x_?NodeQ] := \n  If[LeafQ[x],\n     {x},\n     \
Apply[Join,Map[TreeLeaves,Children[x]]],x]\n",
    FontFamily->"Courier"]
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["TreeExpression[x]",
    FontWeight->"Bold"],
  "\nEspressione corrispondente all'albero generato dal nodo x.",
  StyleBox["\nTreeExpression[x,n]",
    FontWeight->"Bold"],
  "\nEspressione corrispondente all'albero generato dal nodo x, fino al grado \
di discendenza n.",
  "\n",
  StyleBox["TreeDiagram[x]",
    FontWeight->"Bold"],
  "\nRappresentazione grafica dell'albero generato dal nodo x.\n",
  StyleBox["TreeDiagram[x,n]",
    FontWeight->"Bold"],
  "\n",
  "Rappresentazione grafica dell'albero generato dal nodo x, fino al grado di \
discendenza n."
}], "Text"],

Cell[TextData[{
  "ClearAll[TreeExpression,ExpressionDiagram,TreeDiagram]\n",
  StyleBox["\nTreeExpression[x_?NodeQ,n_Integer:-1] := \n  If[LeafQ[x] || n \
== 0,\n     x,\n     Apply[x,Map[TreeExpression[#,n-1]&,Children[x]]]]\n\n",
    FontFamily->"Courier"],
  "ExpressionDiagram",
  StyleBox["[expr_,opts___?OptionQ]",
    FontFamily->"Courier"],
  " := \n  Module[{diagram,x=0,y=0},\n    diagram[e_] := \
Module[{x0=x,x1=x+.6,y0=y,y1=y,\n        s=StringJoin[\" \
\",ToString[If[AtomQ[e],e,Head[e]]],\" \"]},\n      {If[x > 0,\n          \
{Line[{{x-.4,y},{x,y}}]},\n          {}],\n       If[AtomQ[e],\n          \
y-=.2; Nothing, \n          {Line[{{x0,y0},{x1,y0}}],\n           x++; \
Map[(y1=y; diagram[#])&,Apply[List,e]],\n           x--; If[y0==y1,\n         \
          Nothing,\n                   Line[{{x1,y0},{x1,y1}}]]}],  \n       \
Text[StringJoin[s],{x0,y0},{-1,0},Background->GrayLevel[1]]}];\n    \
Show[Graphics[diagram[expr]],\n         \
opts,AspectRatio->Automatic,PlotRange->All]]\n",
  StyleBox["\n",
    FontFamily->"Courier"],
  "TreeDiagram",
  StyleBox["[x_?NodeQ,n_Integer:-1,opts___?OptionQ] := \n  \
ExpressionDiagram[TreeExpression[x,n],opts]\n",
    FontFamily->"Courier"]
}], "Input",
  InitializationCell->True],

Cell[TextData[StyleBox["Messaggi di errore",
  FontWeight->"Bold"]], "Text"],

Cell["\<\
Nodes::node = \"`1` is not a node.\";
Nodes::nodes = \"`1` is not a list of nodes.\";
Nodes::symb = \"`1` is not a symbol.\";
Nodes::make = \"`1` is already a node.\";
Nodes::child = \"`1` is not a child of `2`.\";
Nodes::add = \"`1` is already a child.\";
Nodes::loop = \"`1` is the root of the tree containing `2`.\";
Nodes::insert = \"`1` has already a parent or a child.\";
Nodes::children = \"`1` is not a list of children of `2`.\";  
Nodes::cancel = \"`1` is a root.\";
\
\>", "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{553, 714},
WindowMargins->{{1, Automatic}, {Automatic, 2}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000ad2<?oYonl3<`920dL5N`?P0080001804P000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 241, 9, 36, "Subsubtitle",
  Evaluatable->False],
Cell[1961, 60, 433, 13, 140, "Text"],
Cell[2397, 75, 846, 30, 370, "Input",
  InitializationCell->True],
Cell[3246, 107, 442, 13, 140, "Text"],
Cell[3691, 122, 264, 10, 110, "Input",
  InitializationCell->True],
Cell[3958, 134, 685, 19, 200, "Text"],
Cell[4646, 155, 2089, 62, 786, "Input",
  InitializationCell->True],
Cell[6738, 219, 278, 7, 80, "Text"],
Cell[7019, 228, 1015, 26, 318, "Input",
  InitializationCell->True],
Cell[8037, 256, 301, 8, 95, "Text"],
Cell[8341, 266, 215, 8, 84, "Input",
  InitializationCell->True],
Cell[8559, 276, 419, 11, 125, "Text"],
Cell[8981, 289, 389, 8, 162, "Input",
  InitializationCell->True],
Cell[9373, 299, 600, 17, 170, "Text"],
Cell[9976, 318, 1251, 25, 370, "Input",
  InitializationCell->True],
Cell[11230, 345, 76, 1, 35, "Text"],
Cell[11309, 348, 530, 13, 149, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

