(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14412,        439]*)
(*NotebookOutlinePosition[     40237,       1383]*)
(*  CellTagsIndexPosition[     40193,       1379]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Modellazione", "Subsubtitle"],

Cell[TextData[{
  StyleBox["MakeShape[s,t,...]",
    FontWeight->"Bold"],
  "\nCrea nuovi nodi di tipo Shape associati ai simboli s,t,..., con oggetto, \
geometria e attributi vuoti.\n",
  StyleBox["MakeShape[s,obj]",
    FontWeight->"Bold"],
  "\nCrea il nodo s di tipo Shape che ha come geometria l'oggetto obj.\n",
  StyleBox["MakeShape[s,obj,{a,...}]",
    FontWeight->"Bold"],
  "\nCrea il nodo s di tipo Shape che ha come geometria l'oggetto obj e come \
attributi {a,...}\n",
  StyleBox["ClearShape[s,t...]",
    FontWeight->"Bold"],
  "\nElimina i nodi di tipo Shape s,t,...\n",
  StyleBox["Shapes",
    FontWeight->"Bold"],
  "\nLista dei nodi di tipo Shape definiti mediante MakeShape.\n",
  StyleBox["ShapeQ[x]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se x e' un nodo di tipo Shape."
}], "Text"],

Cell["\<\
ClearAll[MakeShape,ClearShape,Shapes,ShapeQ,Geometry,Apparence]

Shapes := Select[Nodes,ShapeQ];

ShapeQ[_] := False

MakeShape[s_] :=
 If[Not[FreeQ[MakeNode[s],MakeNode]],
    HoldForm[MakeShape[s]],
    s /: ShapeQ[s] = True;
    s /: Geometry[s] = Object[{},{}];
    s /: Apparence[s] = {}; Shapes]

MakeShape[s__] := (Map[MakeShape,{s}]; Shapes)

MakeShape[s_,obj_Object,a_List:{},opts___?OptionQ] :=
 If[Not[FreeQ[MakeShape[s],MakeShape]],
    HoldForm[MakeShape[s,obj,a,opts]],
    Module[{keepnorm = Normals /. Flatten[{opts,Options[MakeShape]}]},
      SetGeometry[s,obj]; SetApparence[s,a]; Shapes]]

ClearShape[s_] :=
  If[Not[ShapeQ[s]],
     Message[Shapes::shape,s]; HoldForm[ClearShape[s]],
     ClearNode[s]; Shapes]

ClearShape[s__] := (Map[ClearShape,{s}]; Shapes)   
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Geometry[s]",
    FontWeight->"Bold"],
  "\nGeometria del nodo di tipo Shape s.\n",
  StyleBox["Apparence[s]",
    FontWeight->"Bold"],
  "\nLista degli attributi del nodo di tipo Shape s.\n",
  StyleBox["SetGeometry[s,g]",
    FontWeight->"Bold"],
  "\nPone la geometria s uguale a g.\n",
  StyleBox["SetApparence[s,{a,...}]",
    FontWeight->"Bold"],
  "\nPone la lista degli attributi di s uguale ad {a,...}\n",
  StyleBox["ClearGeometry[s]",
    FontWeight->"Bold"],
  "\nPone la geometria di s uguale alla geometria vuota.\n",
  StyleBox["ClearApparence[s]",
    FontWeight->"Bold"],
  "\nPone la lista degli attributi di s uguale a {}."
}], "Text"],

Cell["\<\
ClearAll[SetGeometry,SetApparence,ClearGeometry,ClearApparence]

Geometry[s_] := (Message[Shapes::shape,s]; HoldForm[Geometry[s]])

Apparence[s_] := (Message[Shapes::shape,s]; HoldForm[Apparence[s]])

Dim[s_?ShapeQ] := Dim[Geometry[s]]

SetGeometry[s_,g_Object] :=
  If[Not[ShapeQ[s]],
     Message[Shapes::shape,s]; HoldForm[SetGeometry[s,g]],
     s /: Geometry[s] = MapAt[N,g,2] /. 
                          {nc:(_Normals|_Colors) :> MapAt[N,nc,2]}]

SetApparence[s_,a_List] :=
  If[Not[ShapeQ[s]],
     Message[Shapes::shape,s]; HoldForm[SetApparence[s,a]],
     s /: Apparence[s] = a]

ClearGeometry[s_] :=
  If[Not[ShapeQ[s]],
     Message[Shapes::shape,s]; HoldForm[ClearGeometry[s]],
     s /: Geometry[s] = Object[{},{}]]

ClearApparence[s_] :=
  If[Not[ShapeQ[s]],
     Message[Shapes::shape,s]; HoldForm[ClearApparence[s]],
     s /: Apparence[s] = {}]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["PointSize[s]",
    FontWeight->"Bold"],
  "\nAttributo che regola la dimensione dei punti nella visualizzazione.",
  StyleBox["\nPointColor[r,g,b]",
    FontWeight->"Bold"],
  "\nAttributo che regola il colore dei punti nella visualizzazione.\n",
  StyleBox["LineWidth[w]",
    FontWeight->"Bold"],
  "\nAttributo che regola lo spessore delle linee nella visualizzazione.",
  StyleBox["\nLineColor[r,g,b]",
    FontWeight->"Bold"],
  "\nAttributo che regola il colore delle linee nella visualizzazione.\n",
  StyleBox["FillColor[r,g,b]",
    FontWeight->"Bold"],
  "\nAttributo che regola il colore dei poligoni nella visualizzazione.\n",
  StyleBox["EmissiveColor[r,g,b]\n",
    FontWeight->"Bold"],
  "Attributo che regola l'emissione di luce.",
  StyleBox["\nAmbientColor[r,g,b]",
    FontWeight->"Bold"],
  "\nAttributo che regola la diffusione di luce ambiente.",
  StyleBox["\nDiffuseColor[r,g,b]\n",
    FontWeight->"Bold"],
  "Attributo che regola la diffusione di luce da sorgenti luminose.",
  StyleBox["\nSpecularColor[r,g,b]  Shininess[s]\n",
    FontWeight->"Bold"],
  "Attributi che regolano la riflessione di luce da sorgenti luminose.",
  StyleBox["\nPolygonMode[Line]  PolygonMode[Fill]  PolygonMode[Line,Fill]",
    FontWeight->"Bold"],
  "\nAttributo che regola la modalita' di visualizzazione dei poligoni.\n",
  StyleBox["FaceMode[Front]  FaceMode[Back]  FaceMode[Front,Back]",
    FontWeight->"Bold"],
  "\nAttributo che regola la visualizzazione delle due facce dei poligoni."
}], "Text"],

Cell["\<\
ClearAll[PointColor,LineWidth,LineColor,PolygonMode,Fill,
         FaceMode,Front,Back,FillColor,EmissiveColor,
         AmbientColor,DiffuseColor,SpecularColor,Shininess]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["MakeGroup[g,h,...]",
    FontWeight->"Bold"],
  "\nCrea nuovi nodi di tipo Group associati ai simboli g,h,..., con \
trasformazione Identity, lista di componenti {} e lista di selezione {True}.\n\
",
  StyleBox["MakeGroup[g,{x,...}]",
    FontWeight->"Bold"],
  "\nCrea il nodo g di tipo Group che ha come lista di componenti {x,...}.\n\
",
  StyleBox["MakeGroup[g,t,{x,...}]",
    FontWeight->"Bold"],
  "\nCrea il nodo g di tipo Group che ha come trasformazione t e come lista \
di componenti {x,...}.\n",
  StyleBox["ClearGroup[g,h,...]",
    FontWeight->"Bold"],
  "\nElimina i nodi di tipo Group g,h,...\n",
  StyleBox["Groups",
    FontWeight->"Bold"],
  "\nLista dei nodi di tipo Group definiti mediante MakeGroup.\n",
  StyleBox["GroupQ[x]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se x e' un nodo di tipo Group."
}], "Text"],

Cell["\<\
ClearAll[MakeGroup,ClearGroup,Groups,GroupQ,
         Components,Transform,Selection]

Groups := Select[Nodes,GroupQ];

GroupQ[_] := False

MakeGroup[g_] :=
 If[Not[FreeQ[MakeNode[g],MakeNode]],
    HoldForm[MakeGroup[g]],
    g /: GroupQ[g] = True;
    g /: Transform[g] = Identity;
    g /: Selection[g] = {True}; Groups]

MakeGroup[g__] := (Map[MakeGroup,{g}]; Groups)

MakeGroup[g_,l_List] :=
 If[Not[FreeQ[MakeGroup[g],MakeGroup]],HoldForm[MakeGroup[g,l]],
    SetComponents[g,l]; Groups]

MakeGroup[g_,t_,l_List] :=
 If[Not[FreeQ[MakeGroup[g],MakeGroup]],HoldForm[MakeGroup[g,t,l]],
    SetTransform[g,t]; SetComponents[g,l]; Groups]

ClearGroup[g_] :=
  If[Not[GroupQ[g]],
     Message[Groups::group,g]; HoldForm[ClearGroup[g]],
     ClearNode[g]; Groups]

ClearGroup[g__] := (Map[ClearGroup,{g}]; Groups)   
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Transform[g]",
    FontWeight->"Bold"],
  "\nTrasformazione del nodo di tipo Group g.\n",
  StyleBox["Components[g]",
    FontWeight->"Bold"],
  "\nLista dei figli del nodo di tipo Group g.\n",
  StyleBox["Selection[g]",
    FontWeight->"Bold"],
  "\nLista di selezione del nodo di tipo Group g.\n",
  StyleBox["SetTransform[g,t]",
    FontWeight->"Bold"],
  "\nPone la trasformazione g uguale a t.\n",
  StyleBox["SetComponents[g,{x,...}]",
    FontWeight->"Bold"],
  "\nPone la lista delle componenti di g uguale a {x,...}.\n",
  StyleBox["AddComponents[g,{x,...}]",
    FontWeight->"Bold"],
  "\nAggiunge alla lista delle componenti di g gli elementi x,...\n",
  StyleBox["RemoveComponents[g,{x,...}]",
    FontWeight->"Bold"],
  "\nRimuove dalla lista delle componenti di g gli elementi x,...\n",
  StyleBox["SetSelection[g,{s,...}]",
    FontWeight->"Bold"],
  "\nPone la lista di selezione di g uguale a {s,...}.\n",
  StyleBox["ClearTransform[g]",
    FontWeight->"Bold"],
  "\nPone la trasformazione di g uguale all'identita'.\n",
  StyleBox["ClearSelection[g]",
    FontWeight->"Bold"],
  "\nPone la lista di selezione di g uguale a {True}."
}], "Text"],

Cell["\<\
ClearAll[SetTransform,ClearTransform,SetSelection,ClearSelection,
         SetComponents,ClearComponents,AddComponents,RemoveComponents]

Transform[g_] := (Message[Groups::group,g]; HoldForm[Transform[g]])

Components[g_] :=
  If[Not[GroupQ[g]],
     Message[Groups::group,g]; HoldForm[Components[g]],
     Children[g]]

Selection[g_] := (Message[Groups::group,g]; HoldForm[Selection[g]])

Dim[g_?GroupQ] := 
  Module[{c = Components[g]},If[c === {},0,Max[Map[Dim,c]]]]

SetTransform[g_,t_] :=
  If[Not[GroupQ[g]],
     Message[Groups::group,g]; HoldForm[SetTransform[g,t]],
     g /: Transform[g] = t]

ClearTransform[g_] :=
  If[Not[GroupQ[g]],
     Message[Groups::group,g]; HoldForm[ClearTrasform[g]],
     g /: Transform[g] = Identity]
     
SetComponents[g_,l_List] :=
  If[Not[GroupQ[g]],
     Message[Groups::group,g]; HoldForm[SetComponents[g,l]],
   If[Not[Apply[And,Map[Or[ShapeQ[#],GroupQ[#]]&,l]]],
      Message[Groups::comp,l]; HoldForm[SetComponents[g,l]], 
      Module[{d = Union[DeleteCases[Map[Dim,l],0]]},
        If[Length[d] > 1,
           Message[Groups::dim1,l]; HoldForm[SetComponents[g,l]],
           Map[RemoveChildren[1][g,#]&,Children[g]]; 
           Map[AddChildren[1][g,#]&,l]; Components[g]]]]]

ClearComponents[g_] :=
  If[Not[GroupQ[g]],
     Message[Groups::group,g]; HoldForm[ClearComponents[g]],
     Map[RemoveChildren[1][g,#]&,Children[g]]; {}]

AddComponents[g_,l_List] :=
  If[Not[GroupQ[g]],
     Message[Groups::group,g]; HoldForm[AddComponents[g,l]],
   If[Not[Apply[And,Map[Or[ShapeQ[#],GroupQ[#]]&,l]]],
      Message[Nodes::comp,l]; HoldForm[SetComponents[g,l]], 
      Module[{d = Union[DeleteCases[Map[Dim,Append[l,g]],0]]},
        If[Length[d] > 1,
           Message[Groups::dim2,l]; HoldForm[SetComponents[g,l]],
           Map[AddChildren[1][g,#]&,l]; Components[g]]]]]

RemoveComponents[g_,l_List] :=
  If[Not[GroupQ[g]],
     Message[Groups::group,g]; HoldForm[RemoveComponents[g,l]],
   If[Not[Apply[And,Map[Or[ShapeQ[#],GroupQ[#]]&,l]]],
      Message[Groups::comp,l]; HoldForm[SetComponents[g,l]], 
      Map[RemoveChildren[1][g,#]&,l]; Components[g]]]

SetSelection[g_,s_List] :=
  If[Not[GroupQ[g]],
     Message[Groups::group,g]; HoldForm[SetSelection[g,s]],
     g /: Selection[g] = s]

ClearSelection[g_] :=
  If[Not[GroupQ[g]],
     Message[Groups::group,g]; HoldForm[ClearSelection[g]],
     g /: Selection[g] = {True}]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["InsertGroup[g,x,{y,...}]",
    FontWeight->"Bold"],
  "\nInserisce il nodo g di tipo Group tra x e i suoi figli y,....\n",
  StyleBox["CancelGroup[g]",
    FontWeight->"Bold"],
  "\nElimina il nodo di tipo Group g aggiungendo i suoi figli ai figli del \
suo nodo padre."
}], "Text"],

Cell["\<\
InsertGroup[g_,x_,l_List] :=
  If[Not[GroupQ[g]],
     Message[Groups::group,g]; HoldForm[InsertGroup[g,x,l]],
     If[Not[FreeQ[InsertNode[g,x,l],InsertNode]],
        HoldForm[InsertGroup[g,x,l]],g]]

CancelGroup[g_] :=
  If[Not[GroupQ[g]],
     Message[Groups::group,g]; HoldForm[CancelGroup[g]],
     If[Not[FreeQ[CancelNode[g],CancelNode]],
        HoldForm[CancelGroup[g]],g]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["NodeExpand[n]",
    FontWeight->"Bold"],
  "\nObject ottenuto espandendo l'albero generato dal nodo n."
}], "Text"],

Cell["\<\
ClearAll[NodeExpand]

NodeExpand[n_] := 
  Which[ShapeQ[n],
          MapAt[Join[Apparence[n],#]&,Geometry[n],1],
        GroupQ[n],
          Module[{t = Transform[n],
                  l = Thread[And[PadRight[{},Length[Children[n]],
                                          Selection[n]],
                                 Children[n]]] /. False -> Nothing},
            Module[{o = Apply[ObjectUnion,Map[NodeExpand,l]]},
              If[Dim[o] < 2,o,
                 Module[{m = N[If[MatrixQ[t],t,
                                  Switch[Dim[o],2,ExtMatrix2D[t],
                                                3,ExtMatrix3D[t]]]]},
                   ExtMatrixTransform[m,o]]]]],
        True,Message[Nodes::expand, n]; HoldForm[NodeExpand[n]]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[StyleBox["Messaggi di errore",
  FontWeight->"Bold"]], "Text"],

Cell["\<\
Shapes::shape = \"`1` is not a shape node.\";

Groups::group = \"`1` is not a group node.\";
Groups::comp = \"`1` is not a list of components (shapes or groups).\"
Groups::dim1 = \"The components in `1` have not the same dimension.\"
Groups::dim2 = \"Some component in `1` has not the dimension of `2`.\"

Nodes::expand = \"`1` is not a group or shape node.\";
\
\>", "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{556, 713},
WindowMargins->{{51, Automatic}, {-2, Automatic}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000ad2<?oYonl3<`920dL5N`?P0080001804P000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 35, 0, 36, "Subsubtitle"],
Cell[1755, 51, 833, 21, 230, "Text"],
Cell[2591, 74, 838, 30, 370, "Input",
  InitializationCell->True],
Cell[3432, 106, 682, 19, 200, "Text"],
Cell[4117, 127, 918, 31, 383, "Input",
  InitializationCell->True],
Cell[5038, 160, 1539, 34, 350, "Text"],
Cell[6580, 196, 225, 6, 58, "Input",
  InitializationCell->True],
Cell[6808, 204, 887, 23, 245, "Text"],
Cell[7698, 229, 869, 33, 409, "Input",
  InitializationCell->True],
Cell[8570, 264, 1190, 31, 320, "Text"],
Cell[9763, 297, 2443, 70, 890, "Input",
  InitializationCell->True],
Cell[12209, 369, 310, 8, 95, "Text"],
Cell[12522, 379, 436, 14, 162, "Input",
  InitializationCell->True],
Cell[12961, 395, 143, 4, 50, "Text"],
Cell[13107, 401, 805, 20, 240, "Input",
  InitializationCell->True],
Cell[13915, 423, 76, 1, 35, "Text"],
Cell[13994, 426, 414, 11, 123, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

