(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16523,        464]*)
(*NotebookOutlinePosition[     42367,       1409]*)
(*  CellTagsIndexPosition[     42323,       1405]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Oggetti", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["Object[prim]",
    FontWeight->"Bold"],
  "\nGenera un oggetto nella forma Object[str,ver], indicizzando i vertici \
che compaiono nella lista di primitive prim. Colori e normali possono essere \
inseriti nei vertici dopo le coordinate {x,...} nei seguenti modi: \
{x,...,{r,g,b}} per il colore, {x,...,{},{nx,...}} per la normale, \
{x,...,{r,g,b},{nx,...}} per entrambi.",
  StyleBox["\nObject[str,ver]",
    FontWeight->"Bold"],
  "\nOggetto con struttura str costituita da una lista di primitive e \
attributi, dove i vertici sono rappresentati da incidi riferiti alla lista \
dei vertici ver.",
  StyleBox["\nObject[str,ver,Colors[ci,c]]",
    FontWeight->"Bold"],
  "\nOggetto con specificazione di colori per i vertici mediante la lista di \
indici ci e la lista di colori c, espressi nella forma {r,g,b}: il colore \
associato all'i-esimo vertice e' dato da c[[ci[[i]]]].",
  StyleBox["\nObject[str,ver,Normals[ni,n]]\n",
    FontWeight->"Bold"],
  "Oggetto con specificazione di vettori normali per i vertici mediante la \
lista di indici ni e la lista di vettori n: la normale associata all'i-esimo \
vertice e' data da n[[ni[[i]]]].",
  StyleBox["\nObject[str,ver,Colors[ci,c],Normals[ni,n]]\n",
    FontWeight->"Bold"],
  "Oggetto con specificazione di colori e vettori normali per i vertici."
}], "Text"],

Cell["\<\
ClearAll[Object]

Object[l_List] :=
  Module[{s = Chop[l],v,xcn,x,c,n,rv,rc,rn},
    v = Union[Flatten[Cases[s,p:Primitive[___] :>
                              PrimitiveExpand[p],Infinity]]
               /. {Point -> Identity,
                  (Polygon|Line) -> (Apply[Sequence,#]&)}];
    If[v == {},Object[{},{}],
      xcn = Thread[Cases[v,{x__,c_List:{},n_List:{}} :> {{x},c,n}]];
      rv = Dispatch[MapThread[Rule,{v,Range[Length[v]]}]];
      c = Union[xcn[[2]],{{}}];
      rc = Dispatch[MapThread[Rule,{c,Range[0,Length[c] - 1]}]];
      n = Union[xcn[[3]],{{}}];
      rn = Dispatch[MapThread[Rule,{n,Range[0,Length[n] - 1]}]];
      Object[s /. rv,xcn[[1]],
        If[c =!= {{}},Colors[xcn[[2]] /. rc,Rest[c]],Nothing],
        If[n =!= {{}},Normals[xcn[[3]] /. rn,Rest[n]],Nothing]]]]

Format[Object[{},__]] = \"\[SkeletonIndicator]EmptyObject\[SkeletonIndicator]\
\";
Format[Object[_,{},___]] = \"\[SkeletonIndicator]EmptyObject\
\[SkeletonIndicator]\";
Format[Object[_,_?VectorQ,___]] = \"\[SkeletonIndicator]Object1D\
\[SkeletonIndicator]\";
Format[Object[_,{{_,_},___},___]] = \"\[SkeletonIndicator]Object2D\
\[SkeletonIndicator]\";
Format[Object[_,{{_,_,_},___},___]] = \"\[SkeletonIndicator]Object3D\
\[SkeletonIndicator]\";
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Structure[obj]",
    FontWeight->"Bold"],
  "\nLista delle primitive e degli attributi dell'oggetto obj.\n",
  StyleBox["Vertices[obj]",
    FontWeight->"Bold"],
  "\nVertici dell'oggetto obj.\n",
  StyleBox["Colors[obj]",
    FontWeight->"Bold"],
  "\nColori associati ai vertici dell'oggetto obj.\n",
  StyleBox["Normals[obj]",
    FontWeight->"Bold"],
  "\nNormali associate ai vertici dell'oggetto obj.\n",
  StyleBox["Dim[obj]",
    FontWeight->"Bold"],
  "\nDimensione dell'oggetto obj."
}], "Text"],

Cell["\<\
ClearAll[Structure,Vertices,Colors,Normals,Dim]

Structure[Object[s_,_,___]] := s

Vertices[Object[_,v_,___]] := v

Colors[Object[__,c_Colors,___]] := c
Colors[Object[_,v_,___]] := Colors[Table[0,{Length[v]}],{}]
  
Normals[Object[__,n_Normals,___]] := n
Normals[Object[_,v_,___]] := Normals[Table[0,{Length[v]}],{}]
  
Dim[Object[s_,v_,___]] :=
  Which[v == {},0,VectorQ[v],1,True,Dimensions[v][[2]]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["AddAttributes[obj,{a,...}]",
    FontWeight->"Bold"],
  "\nOggetto ottenuto integrando gli attributi {a,...} nella struttura \
dell'oggetto obj.\n",
  StyleBox["RemoveAttributes[obj]",
    FontWeight->"Bold"],
  "\nOggetto ottenuto eliminando dalla struttura di obj gli attributi."
}], "Text"],

Cell["\<\
Clear[AddAttributes,RemoveAttributes]

AddAttributes[Object[s_,v_,r___],a_List] := Object[Append[a,s],v,r]

RemoveAttributes[Object[s_,v_,r___]] :=
  Object[DeleteCases[s,_?(Not[PrimitiveQ[#]]&),Infinity],v,r]
  \
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["AddColors[obj,Colors[ci,c]]",
    FontWeight->"Bold"],
  "\nOggetto ottenuto da obj aggiungendo (o sostituendo) i colori.\n",
  StyleBox["AddNormals[obj,Normals[ni,n]]",
    FontWeight->"Bold"],
  "\nOggetto ottenuto da obj aggiungendo (o sostituendo) le normali.\n",
  StyleBox["RemoveColors[obj]",
    FontWeight->"Bold"],
  "\nOggetto ottenuto da obj con eliminando i colori.\n",
  StyleBox["RemoveNormals[obj]",
    FontWeight->"Bold"],
  "\nOggetto ottenuto da obj eliminando le normali."
}], "Text"],

Cell["\<\
ClearAll[AddColors,AddNormals,RemoveColors,RemoveNormals]

AddColors[obj_Object,c_Colors] := Append[RemoveColors[obj],c]
AddNormals[obj_Object,n_Normals] := Append[RemoveNormals[obj],n]

RemoveColors[obj_Object] := DeleteCases[obj,_Colors]
RemoveNormals[obj_Object] := DeleteCases[obj,_Normals]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["ObjectExpand[obj]",
    FontWeight->"Bold"],
  "\nEspansione dell'oggetto obj."
}], "Text"],

Cell["\<\
ClearAll[ObjectExpand]

ObjectExpand[Object[s_,r__]] := 
  Object[s /. p:Primitive[___] :> PrimitiveExpand[p],r]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["ObjectNormalize[obj]",
    FontWeight->"Bold"],
  "\nNormalizzazione dell'oggetto obj mediante reindicizzazione dei vertici."
}], "Text"],

Cell["\<\
ClearAll[ObjectNormalize]

ObjectNormalize[obj:Object[s_,v_,___]] := 
  Module[{col = Colors[obj],nor = Normals[obj],ci,c,ni,n},
    ci = col[[1]] + 1; c = Prepend[col[[2]],{}];
    ni = nor[[1]] + 1; n = Prepend[nor[[2]],{}];
  Object[(s /. p:Primitive[___] :> PrimitiveExpand[p])
            /. {Point[x_] :> 
                  Point[Join[v[[x]],{c[[ci[[x]]]],n[[ni[[x]]]]}]],
                (p:Line|Polygon)[x_] :> 
                  p[MapThread[Join[#1,{#2,#3}]&,
                      {v[[x]],c[[ci[[x]]]],n[[ni[[x]]]]}]]}]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["ObjectUnion[obj1,obj2,...]\n",
    FontWeight->"Bold"],
  "Unione degli oggetti obj1,obj2,..."
}], "Text"],

Cell["\<\
ClearAll[ObjectUnion]
SetAttributes[ObjectUnion,{Flat,OneIdentity}];

ObjectUnion[obj_] := obj
ObjectUnion[obj_Object,Object[{},___]] := obj
ObjectUnion[Object[{},___],obj_Object] := obj

ObjectUnion[obj1_Object,obj2_Object] := 
  Object[{Structure[obj1],Structure[obj2] /. 
             p:Primitive[___] :> (p /. i_Integer -> i + 
                                           Length[Vertices[obj1]])},
         Join[Vertices[obj1],Vertices[obj2]],
    If[Not[MemberQ[Join[obj1,obj2],Colors[__]]],Nothing,
       Module[{c1 = Colors[obj1],c2 = Colors[obj2]},
         Colors[Join[c1[[1]],c2[[1]] + Sign[c2[[1]]] Length[c1[[2]]]],
                Join[c1[[2]],c2[[2]]]]]],
    If[Not[MemberQ[Join[obj1,obj2],Normals[__]]],Nothing,
       Module[{n1 = Normals[obj1],n2 = Normals[obj2]},
         Normals[Join[n1[[1]],n2[[1]] + Sign[n2[[1]]] Length[n1[[2]]]],
                 Join[n1[[2]],n2[[2]]]]]]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["LinearTransform[l,obj]",
    FontWeight->"Bold"],
  "\nTrasformato dell'oggetto obj mediante la trasformazione lineare l.\n",
  StyleBox["MatrixTransform[m,obj]",
    FontWeight->"Bold"],
  "\nTrasformato dell'oggetto obj mediante la matrice m.\n",
  StyleBox["AffineTransform[t,obj]",
    FontWeight->"Bold"],
  "\nTrasformato dell'oggetto obj mediante la trasformazione affine t.\n",
  StyleBox["ExtMatrixTransform[m,obj]",
    FontWeight->"Bold"],
  "\nTrasformato dell'oggetto obj mediante la matrice estesa m.\n",
  StyleBox["FunctionalTransform[f,obj]\nCompiledTransform[f,obj]",
    FontWeight->"Bold"],
  "\nTrasformato dell'oggetto obj mediante l'applicazione f, nelle versioni \
non compilata e compilata."
}], "Text"],

Cell["\<\
ClearAll[LinearTransform,MatrixTransform,
         AffineTransform,ExtMatrixTransform,
         FunctionalTransform,CompiledTransform]

LinearTransform[l_,obj_Object] := 
  MatrixTransform[Switch[Dim[obj],
                    2,Matrix2D[l],
                    3,Matrix3D[l]],obj]

MatrixTransform[m_?MatrixQ,obj_Object] := 
  Object[Structure[obj],Vertices[obj] . m,
    If[Not[MemberQ[obj,Colors[__]]],
       Nothing,
       Colors[obj]],
    If[Not[MemberQ[obj,Normals[__]]],
       Nothing,
       Module[{n = Normals[obj]},
         Normals[n[[1]],n[[2]] . Inverse[Transpose[m]]]]]]

AffineTransform[l_,obj_Object] := 
  ExtMatrixTransform[Switch[Dim[obj],
                       2,ExtMatrix2D[l],
                       3,ExtMatrix3D[l]],obj]

ExtMatrixTransform[m_?MatrixQ,obj_Object] := 
  Object[Structure[obj],
    Module[{x = Vertices[obj]}, 
      PadLeft[{},{Length[x]},{First[m]}] + x . Rest[m]],
    If[Not[MemberQ[obj,Colors[__]]],
       Nothing,
       Colors[obj]],
    If[Not[MemberQ[obj,Normals[__]]],
       Nothing,
       Module[{n = Normals[obj]},
         Normals[n[[1]],n[[2]] . Inverse[Thread[Rest[m]]]]]]]

FunctionalTransform[f_,Object[s_,v_,cn___]] := Object[s,Map[f,v],cn]

CompiledTransform[f_,obj:Object[s_,v_,cn___]] :=
  Object[s,CompiledTransform[f,Dim[obj],v],cn]
           
CompiledTransform[f_,n_,l_List] :=
  Switch[n,1,Map[Compile[X,Evaluate[f[X]]],l],
           2,Apply[Compile[{X,Y},Evaluate[f[{X,Y}]]],l,1],
           3,Apply[Compile[{X,Y,Z},Evaluate[f[{X,Y,Z}]]],l,1]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["LinearClip[obj,v,c]\n",
    FontWeight->"Bold"],
  "Intersezione dell'oggetto obj con il semispazio determinato dalla \
disequazione x . v <= c.\n",
  StyleBox["LinearClip[obj,{v1,c1},{v2,c2},...]\n",
    FontWeight->"Bold"],
  "Intersezione dell'oggetto obj con il dominio determinato dalle \
disequazioni x . v1 <= c1, x . v2 <= c2 , ...\n",
  StyleBox["FunctionalClip[obj,f,c]\nCompiledClip[obj,f,c]\n",
    FontWeight->"Bold"],
  "Intersezione dell'oggetto obj con il dominio determinato dalla \
disequazione f[x] <= c, nella versione non compilata e compilata."
}], "Text"],

Cell["\<\
ClearAll[LinearClip,FunctionalClip,CompiledClip,TableClip]
Options[TableClip] = {Expand -> True,Normalize -> True};

LinearClip[obj_Object,opts___?OptionQ] := obj

LinearClip[obj_Object,{v_List,c_},r___,opts___?OptionQ] := 
  LinearClip[LinearClip[obj,v,c],r,opts]

LinearClip[Object[_,{},___],___] := Object[{},{}]
LinearClip[obj_Object,v_,c_,opts___?OptionQ] := 
  TableClip[obj,c - Vertices[obj] . v,opts]

FunctionalClip[Object[_,{},___],___] := Object[{},{}]
FunctionalClip[obj_Object,f_,c_,opts___?OptionQ] := 
  TableClip[obj,c - Map[f,Vertices[obj]],opts]  

CompiledClip[Object[_,{},___],___] := Object[{},{}]
CompiledClip[obj_Object,f_,c_,opts___?OptionQ] := 
  TableClip[obj,c - CompiledTransform[f,Dim[obj],Vertices[obj]],opts]  

TableClip[Object[_,{},___],___] := Object[{},{}]
TableClip[obj:Object[s_,v_,___],l_List,opts___?OptionQ] :=
  Module[{nv = v,NewVertex,lx,sx,
          cflag = MemberQ[obj,Colors[___]],nci,nc,
          nflag = MemberQ[obj,Normals[___]],nni,nn,
          exp = Expand /. Flatten[{opts,Options[TableClip]}],
          nor = Normalize /. Flatten[{opts,Options[TableClip]}]},
    If[cflag,nci = Colors[obj][[1]]; nc = Colors[obj][[2]]];
    If[nflag,nni = Normals[obj][[1]]; nn = Normals[obj][[2]]];
    NewVertex[{v1_,v2_},{i1_,i2_}] := 
      (AppendTo[nv,(v2 nv[[i1]] - v1 nv[[i2]])/(v2-v1)];
       If[cflag,AppendTo[nc,(v2 nc[[nci[[i1]]]] - 
                             v1 nc[[nci[[i2]]]])/(v2-v1)];
                AppendTo[nci,Length[nc]]];
       If[nflag,AppendTo[nn,(v2 nc[[nni[[i1]]]] - 
                             v1 nc[[nni[[i2]]]])/(v2-v1)];
                AppendTo[nni,Length[nn]]];
       Length[nv]);
    Object[If[exp,s /. p:Primitive[___] :> PrimitiveExpand[p],s] /.
      {Point[x_] :> If[l[[x]] >= 0,Point[x],Nothing],
            Line[x_] :>
              Switch[Sign[lx = l[[x]]],
                {-1,-1},Nothing,{0|1,0|1},Line[x],
                {_,1},Line[{NewVertex[lx,x],Last[x]}],               
                {1,_},Line[{First[x],NewVertex[lx,x]}],   
                {_,0}|{0,_},Nothing],
            Polygon[x_] :>
              Switch[sx = Sign[lx = l[[x]]],
                {-1 ...},Nothing,{(0|1) ...},Polygon[x],
                _,Module[{p = Position[Partition[
                          Prepend[sx,Last[sx]],2,1],{-1,0|1}][[1,1]]},
                    Module[{y = RotateLeft[x,p - 1],
                            ly = RotateLeft[lx,p - 1],
                            sy = RotateLeft[sx,p - 1],q},
                      Replace[sy,
                       {{0,-1,___}|{0,0,-1,___} :> Nothing,
                        {0,a__,0,-1,___} :>
                          Polygon[Take[y,Length[{a}] + 2]],
                        {0,a___,1,-1,___} :>
                          Polygon[Append[Take[y,q = Length[{a}] + 2],
                            NewVertex[ly[[{q,q+1}]],y[[{q,q+1}]]]]],
                        {1,a___,0,-1,___} :>
                          Polygon[Append[Take[y,q = Length[{a}] + 2],
                            NewVertex[ly[[{-1,1}]],y[[{-1,1}]]]]],
                        {a___,-1,___} :>
                          Polygon[Join[Take[y,q = Length[{a}]],
                            {NewVertex[ly[[{q,q+1}]],y[[{q,q+1}]]],
                             NewVertex[ly[[{-1,1}]],y[[{-1,1}]]]}]]}
                         ]]]]},
        nv,If[cflag,Colors[nci,nc],Nothing],
           If[nflag,Normals[nni,nn],Nothing]] //
                                   If[nor,ObjectNormalize,Identity]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["ExportObject[obj,filename]\n",
    FontWeight->"Bold"],
  "Esporta l'oggetto obj nel file specificato in formato .obj (senza colori, \
normali e attributi)."
}], "Text"],

Cell["\<\
ClearAll[ExportObject]

ExportObject[obj_Object,filename_] :=
  
Module[{s = Structure[ObjectExpand[obj]]},
  Module[{v = Map[Prepend[#,\"v\"]&,Chop[Vertices[obj]] + 0.],
          l = Cases[s,Line[x_] :> Prepend[x,\"l\"],Infinity],
          p = Cases[s,Polygon[x_] :> Prepend[x,\"f\"],Infinity],f},
    f = OpenWrite[StringJoin[filename,\".obj\"]];
    WriteString[f,
      TableForm[v,TableSpacing->{0,1}],\"\\n\",
      TableForm[l,TableSpacing->{0,1}],\"\\n\",
      TableForm[p,TableSpacing->{0,1}],\"\\n\",
      FromCharacterCode[20]];
    Close[f];]]
 \
\>", "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{555, 688},
WindowMargins->{{107, Automatic}, {15, Automatic}},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000ad2<?oYonl3<`920dL5N`?P0080001804P000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 242, 9, 36, "Subsubtitle",
  Evaluatable->False],
Cell[1962, 60, 1345, 26, 320, "Text"],
Cell[3310, 88, 1300, 32, 331, "Input",
  InitializationCell->True],
Cell[4613, 122, 533, 16, 170, "Text"],
Cell[5149, 140, 455, 17, 201, "Input",
  InitializationCell->True],
Cell[5607, 159, 321, 8, 95, "Text"],
Cell[5931, 169, 265, 9, 97, "Input",
  InitializationCell->True],
Cell[6199, 180, 533, 13, 140, "Text"],
Cell[6735, 195, 348, 10, 110, "Input",
  InitializationCell->True],
Cell[7086, 207, 119, 4, 50, "Text"],
Cell[7208, 213, 166, 7, 71, "Input",
  InitializationCell->True],
Cell[7377, 222, 165, 4, 50, "Text"],
Cell[7545, 228, 584, 15, 175, "Input",
  InitializationCell->True],
Cell[8132, 245, 134, 4, 50, "Text"],
Cell[8269, 251, 951, 23, 279, "Input",
  InitializationCell->True],
Cell[9223, 276, 756, 17, 200, "Text"],
Cell[9982, 295, 1572, 48, 604, "Input",
  InitializationCell->True],
Cell[11557, 345, 606, 13, 170, "Text"],
Cell[12166, 360, 3536, 75, 955, "Input",
  InitializationCell->True],
Cell[15705, 437, 197, 5, 65, "Text"],
Cell[15905, 444, 614, 18, 214, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

