(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10533,        336]*)
(*NotebookOutlinePosition[     36377,       1281]*)
(*  CellTagsIndexPosition[     36333,       1277]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Primitive", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["Primitive",
    FontWeight->"Bold"],
  "\nPattern costituito dall'alternativa di tutte le primitive definite.\n",
  StyleBox["Primitives",
    FontWeight->"Bold"],
  "\nLista delle primitive definite mediante MakePrimitive.\n",
  StyleBox["PrimitiveQ[x]",
    FontWeight->"Bold"],
  "\nEspressione booleana che controlla se x e' una primitiva definita."
}], "Text"],

Cell["\<\
ClearAll[Primitive,Primitives,PrimitiveQ]

Primitive = Alternatives[];
Primitives := Apply[List,Primitive]
PrimitiveQ[x_] := MatchQ[Head[x],Primitive]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["MakePrimitive[prim,{x,...},exp]",
    FontWeight->"Bold"],
  "\nCrea la primitiva prim con parametri x,... (che devono essere pattern) \
la cui espansione in termini di Point, Line e Polygon e' data \
dall'espressione exp.\n",
  StyleBox["ExtendPrimitive[prim,{x,...},exp]",
    FontWeight->"Bold"],
  "\nEstende la definizione della primitiva prim gia' esistente.\n",
  StyleBox["ClearPrimitive[prim]",
    FontWeight->"Bold"],
  "\nElimina la primitiva prim.\n",
  StyleBox["PrimitiveExpand[prim]",
    FontWeight->"Bold"],
  "\nEspansione della primitiva prim in termini di Point, Line, Polygon."
}], "Text"],

Cell["\<\
ClearAll[MakePrimitive,RemovePrimitive,PrimitiveExpand]
SetAttributes[MakePrimitive,HoldAll];

MakePrimitive[prim_Symbol,l_List,expr_] := 
  If[PrimitiveQ[prim],
     Message[Primitive::make,prim];
       HoldForm[MakePrimitive[prim,l,expr]],
     ClearAll[prim];
       Primitive = Union[Primitive,Alternatives[prim]]; 
       prim/: PrimitiveExpand[Apply[prim,l]] := expr; prim]
       
ExtendPrimitive[prim_Symbol,l_List,expr_] := 
  If[Not[PrimitiveQ[prim]],
     Message[Primitive::primitive,prim];
       HoldForm[ExtendPrimitive[prim,l,expr]],
       prim/: PrimitiveExpand[Apply[prim,l]] := expr; prim]

ClearPrimitive[prim_Symbol] := 
  If[Not[PrimitiveQ[prim]], 
     Message[Primitive::primitive,prim];
       HoldForm[ClearPrimitive[prim]], 
     DeleteCases[Primitive,prim]; ClearAll[prim]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Point[x]  Point[{x,y}]  Point[{x,y,z}]",
    FontWeight->"Bold"],
  "\nPunto di coordinate date in dimensione 1,2 e 3.\n",
  StyleBox["Line[{x1,x2}]  Line[{{x1,y1},{x2,y2}}]  \
Line[{{x1,y1,z1},{x2,y2,z2}}]",
    FontWeight->"Bold"],
  "\nSegmento di estremi dati in dimensione 1,2 e 3.\n",
  StyleBox["Polygon[{{x1,y1},...,{xn,yn}}]  \
Polygon[{{x1,y1,z1},...,{xn,yn,zn}}]",
    FontWeight->"Bold"],
  "\nPoligono di vertici dati in dimensione 2 e 3."
}], "Text"],

Cell["\<\
Unprotect[Point,Line,Polygon]; 
ClearAll[Point,Line,Polygon]; 
 
MakePrimitive[Point,{x_},Point[x]]; 
MakePrimitive[Line,{l_List},Line[l]]; 
MakePrimitive[Polygon,{l_List},Polygon[l]];

Protect[Point,Line,Polygon];
  \
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["PointArray[{x1,...,xn}]",
    FontWeight->"Bold"],
  "\nLista dei punti di coordinate x1,...,xn\n",
  StyleBox["LineArray[{{x11,x12},...,{xn1,xn2}}]",
    FontWeight->"Bold"],
  "\nLista dei segmenti di estremi {x11,x12},...,{xn1,xn2}.\n",
  StyleBox["PoligonArray[{{x11,...,x1h},...,{xn1,...,xnk}}]\n",
    FontWeight->"Bold"],
  "Lista dei poligoni di vertici {x11,...,x1h},...,{xn1,...,xnk}."
}], "Text"],

Cell["\<\
MakePrimitive[PointArray,{l_List},Map[Point,l]];
MakePrimitive[LineArray,{l_List},Map[Line,l]];
MakePrimitive[PolygonArray,{l_List},Map[Polygon,l]];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["LineStrip[{x1,...,xn}]",
    FontWeight->"Bold"],
  "\nPoligonale di vertici x1,...xn.",
  "\n",
  StyleBox["LineStripArray[{{x11,...,x1h},...,{xn1,...,xnk}}]",
    FontWeight->"Bold"],
  "\n",
  "Lista dei poligonali di vertici {x11,...,x1h},...,{xn1,...,xnk}."
}], "Text"],

Cell["\<\
MakePrimitive[LineStrip,{l_List},Map[Line,Partition[l,2,1]]];

MakePrimitive[LineStripArray,{l_List},
  Flatten[Map[PrimitiveExpand[LineStrip[#1]]&,l]]];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["TriangleArray[{x1,x2,x3,...,x3n}]",
    FontWeight->"Bold"],
  "\nLista dei triangoli di vertici {x1,x2,x3},{x4,x5,x6},...",
  StyleBox["\nQuadArray[{x1,x2,x3,x4,...,x4n}]",
    FontWeight->"Bold"],
  "\nLista dei quadrilateri di vertici {x1,x2,x3,x4},{x5,x6,x7,x8},..."
}], "Text"],

Cell["\<\
MakePrimitive[TriangleArray,{l_List},Map[Polygon,Partition[l,3]]];

MakePrimitive[QuadArray,{l_List},Map[Polygon,Partition[l,4]]];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["TriangleStrip[{x1,x2,x3,...,xn}]",
    FontWeight->"Bold"],
  StyleBox["\n",
    FontWeight->"Bold"],
  "Lista dei triangoli di vertici {x1,x2,x3},{x2,x3,x4},{x3,x4,x5},...\n",
  StyleBox["TriangleStripArray[{{x11,...,x1h},...,{xn1,...,xnk}}]\n",
    FontWeight->"Bold"],
  "Lista di TriangleStrip corrispondenti alle liste di vertici date."
}], "Text"],

Cell["\<\
MakePrimitive[TriangleStrip,{l_List},
  Table[If[OddQ[i],
           Polygon[l[[{i,i+2,i+1}]]],
           Polygon[l[[{i,i+1,i+2}]]]],
        {i,Length[l]-2}]];

MakePrimitive[TriangleStripArray,{l_List},
  Flatten[Map[PrimitiveExpand[TriangleStrip[#1]]&,l]]];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["TriangleFan[{x1,x2,x3,...,xn}]\n",
    FontWeight->"Bold"],
  "Lista dei triangoli di vertici {x1,x2,x3},{x1,x3,x4},{x1,x4,x5},...\n",
  StyleBox["TriangleFanArray[{{x11,...,x1h},...,{xn1,...,xnk}}]\n",
    FontWeight->"Bold"],
  "Lista di TriangleFan corrispondenti alle liste di vertici date."
}], "Text"],

Cell["\<\
MakePrimitive[TriangleFan,{l_List},
  Map[Polygon[{l[[1]],#1[[1]],#1[[2]]}]&,Partition[Rest[l],2,1]]];

MakePrimitive[TriangleFanArray,{l_List},
  Flatten[Map[PrimitiveExpand[TriangleFan[#1]]&,l]]];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["TrianglePatch[{{x11,...,x1h},...,{xn1,...,xnk}}]\n",
    FontWeight->"Bold"],
  "Lista di TriangleStrip generate dalle liste di vertici che si ottengono \
intercalando gli elenti delle liste date considerate a coppie consecutive. \
Ciascuna delle liste date deve avere lunghezza uguale o minore di uno \
rispetto a quella precedente.\n",
  StyleBox["TrianglePatchArray[{{x11,...,x1h},...,{xn1,...,xnk}}]\n",
    FontWeight->"Bold"],
  "Lista di TrianglePatch corrispondenti alle liste di vertici date."
}], "Text"],

Cell["\<\
MakePrimitive[TrianglePatch,{l_List},
  If[Length[l] < 2, {}, 
     Module[{l1 = l[[1]],l2 = l[[2]]},
       Module[{s = Flatten[Join[Thread[Take[l,2,Length[l2]]],
                    If[Length[l1]>Length[l2],{Last[l1]},{}]],1]},
         Join[PrimitiveExpand[TriangleStrip[s]], 
              PrimitiveExpand[TrianglePatch[Rest[l]]]]]]]];

MakePrimitive[TrianglePatchArray,{l_List},
  Flatten[Map[PrimitiveExpand[TrianglePatch[#1]]&,l]]];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["QuadStrip[{x1,x2,x3,x4,...,x2n}]",
    FontWeight->"Bold"],
  StyleBox["\n",
    FontWeight->"Bold"],
  "Lista dei quadrilateri di vertici {x1,x2,x3,x4}, {x3,x4,x5,x6},...\n",
  StyleBox["QuadStripArray[{{x11,...,x1h},...,{xn1,...,xnk}}]\n",
    FontWeight->"Bold"],
  "Lista di QuadStrip corrispondenti alle liste di vertici date."
}], "Text"],

Cell["\<\
MakePrimitive[QuadStrip,{l_List},
  Map[Polygon[#1[[{1,3,4,2}]]]&,Partition[l,4,2]]];

MakePrimitive[QuadStripArray,{l_List},
  Flatten[Map[PrimitiveExpand[QuadStrip[#1]]&,l]]];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["QuadPatch[{{x11,...,x1h},...,{xn1,...,xnh}}]\n",
    FontWeight->"Bold"],
  "Lista di TriangleStrip generate dalle liste di vertici che si ottengono \
intercalando gli elenti delle liste date considerate a coppie consecutive. \
Tutte le liste date devono avere la stessa lunghezza, formando quindi una \
matrice rettangolare n x h.\n",
  StyleBox["QuadPatchArray[{{x11,...,x1h},...,{xn1,...,xnk}}]",
    FontWeight->"Bold"],
  StyleBox["\n",
    FontWeight->"Bold"],
  "Lista di QuadPatch corrispondenti alle matrici di vertici date."
}], "Text"],

Cell["\<\
MakePrimitive[QuadPatch,{l_List},
  Map[Polygon[Join[#1[[1]],Reverse[#1[[2]]]]]&,
      Flatten[Partition[l,{2,2},{1,1}],1]]];

MakePrimitive[QuadPatchArray,{l_List},
  Flatten[Map[PrimitiveExpand[QuadPatch[#1]]&,l]]];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[StyleBox["Messaggi di errore",
  FontWeight->"Bold"]], "Text"],

Cell["\<\
Primitives::make = \"`1` is already a primitive.\";
Primitives::primitive = \"`1` is not a primitive.\";
\
\>", "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{555, 688},
WindowMargins->{{Automatic, 157}, {Automatic, 15}},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000ad2<?oYonl3<`920dL5N`?P0080001804P000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 244, 9, 36, "Subsubtitle",
  Evaluatable->False],
Cell[1964, 60, 393, 10, 110, "Text"],
Cell[2360, 72, 204, 8, 84, "Input",
  InitializationCell->True],
Cell[2567, 82, 639, 15, 170, "Text"],
Cell[3209, 99, 857, 25, 305, "Input",
  InitializationCell->True],
Cell[4069, 126, 492, 12, 140, "Text"],
Cell[4564, 140, 270, 11, 123, "Input",
  InitializationCell->True],
Cell[4837, 153, 435, 10, 110, "Text"],
Cell[5275, 165, 202, 6, 58, "Input",
  InitializationCell->True],
Cell[5480, 173, 302, 9, 80, "Text"],
Cell[5785, 184, 207, 7, 71, "Input",
  InitializationCell->True],
Cell[5995, 193, 310, 7, 80, "Text"],
Cell[6308, 202, 184, 6, 58, "Input",
  InitializationCell->True],
Cell[6495, 210, 381, 9, 80, "Text"],
Cell[6879, 221, 315, 11, 123, "Input",
  InitializationCell->True],
Cell[7197, 234, 335, 7, 80, "Text"],
Cell[7535, 243, 252, 8, 84, "Input",
  InitializationCell->True],
Cell[7790, 253, 542, 10, 125, "Text"],
Cell[8335, 265, 493, 13, 149, "Input",
  InitializationCell->True],
Cell[8831, 280, 372, 9, 80, "Text"],
Cell[9206, 291, 231, 8, 84, "Input",
  InitializationCell->True],
Cell[9440, 301, 574, 12, 125, "Text"],
Cell[10017, 315, 272, 9, 97, "Input",
  InitializationCell->True],
Cell[10292, 326, 76, 1, 35, "Text"],
Cell[10371, 329, 158, 5, 45, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

