(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15720,        462]*)
(*NotebookOutlinePosition[     41546,       1406]*)
(*  CellTagsIndexPosition[     41502,       1402]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Trasformazioni", "Subsubtitle"],

Cell[TextData[{
  StyleBox["Translate2D[{tx,ty}]",
    FontWeight->"Bold"],
  "\nTraslazione del piano corrispondente al vettore {tx,ty}",
  "\n",
  StyleBox["Translate3D[{tx,ty,tz}]",
    FontWeight->"Bold"],
  "\n",
  "Traslazione dello spazio corrispondente al vettore {tx,ty,tz}"
}], "Text"],

Cell["\<\
ClearAll[Translate2D,Translate3D] 

Translate2D[t:{_,_}][x:{_,_}] := x + t
Translate3D[t:{_,_,_}][x:{_,_,_}] := x + t
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Rotate2D[X,Y] Rotate2D[Y,X]",
    FontWeight->"Bold"],
  "\nRotazione del piano x,y con centro l'origine che porta il versore \
canonico indicato dal primo parametro in quello indicato dal secondo. \n",
  StyleBox["Rotate2D[a]",
    FontWeight->"Bold"],
  "\nRotazione del piano con centro l'origine e angolo di rotazione a.\n",
  StyleBox["Rotate2D[c,a]",
    FontWeight->"Bold"],
  "\nRotazione del piano con centro c e angolo di rotazione a."
}], "Text",
  AspectRatioFixed->True],

Cell["\<\
ClearAll[Rotate2D]

Rotate2D[X,Y][{x_,y_}] := {-y,x}
Rotate2D[Y,X][{x_,y_}] := {y,-x}

Rotate2D[a_][{x_,y_}] := {x Cos[a] - y Sin[a],x Sin[a] + y Cos[a]}
Rotate2D[c:{_,_},a_][x:{_,_}] := 
  Composition[Translate2D[c],Rotate2D[a],Translate2D[-c]][x]
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Rotate3D[X,Y]  Rotate3D[Y,Z]  Rotate3D[Z,X]\nRotate3D[X,Z]  \
Rotate3D[Z,Y]  Rotate3D[Y,X]",
    FontWeight->"Bold"],
  "\nRotazione dello spazio x,y,z con centro l'origine che porta il versore \
canonico indicato dal primo parametro in quello indicato dal secondo, tenendo \
fisso il terzo non indicato.\n",
  StyleBox["Rotate3D[X,Y,Z]  Rotate3D[Z,Y,X]",
    FontWeight->"Bold"],
  "\nRotazione dello spazio x,y,z con centro l'origine che permuta \
ciclicamente i tre versori canonici nell'ordine indicato dai tre parametri.\n\
",
  StyleBox["Rotate3D[X,{b1,b2}]  Rotate3D[Y,{b1,b2}]  Rotate3D[Z,{b1,b2}]\n\
Rotate3D[{b1,b2},X]  Rotate3D[{b1,b2},Y]  Rotate3D[{b1,b2},Z]",
    FontWeight->"Bold"],
  "\nRotazione dello spazio x,y,z con centro l'origine che porta il versore \
canonico indicato in quello individuato dalla coppia di angoli {b1,b2} e \
viceversa.\n",
  StyleBox["Rotate3D[X,a]  Rotate3D[Y,a]  Rotate3D[Z,a]",
    FontWeight->"Bold"],
  "\nRotazione dello spazio x,y,z di un angolo a intorno all'asse coordinato \
indicato dal primo parametro.\n",
  StyleBox["Rotate3D[{b1,b2},a]",
    FontWeight->"Bold"],
  "\nRotazione dello spazio con centro l'origine, asse di rotazione \
individuato dalla coppia di angoli {b1,b2} e angolo di rotazione a.\n",
  StyleBox["Rotate3D[c,{b1,b2},a]",
    FontWeight->"Bold"],
  "\nRotazione dello spazio con centro c, asse di rotazione individuato dalla \
coppia di angoli {b1,b2} e angolo di rotazione a."
}], "Text",
  AspectRatioFixed->True],

Cell["\<\
ClearAll[Rotate3D]

Rotate3D[X,Y][{x_,y_,z_}] := {-y,x,z}
Rotate3D[Y,Z][{x_,y_,z_}] := {x,-z,y}
Rotate3D[Z,X][{x_,y_,z_}] := {z,y,-x}
Rotate3D[X,Z][{x_,y_,z_}] := {-z,y,x}
Rotate3D[Y,X][{x_,y_,z_}] := {y,-x,z}
Rotate3D[Z,Y][{x_,y_,z_}] := {x,z,-y}

Rotate3D[X,Y,Z][{x_,y_,z_}] := {z,x,y}
Rotate3D[Z,Y,X][{x_,y_,z_}] := {y,z,x}

Rotate3D[X,{b1_,b2_}][x:{_,_,_}] := 
  Composition[Rotate3D[Z,b1],Rotate3D[Y,-b2]][x]
Rotate3D[{b1_,b2_},X][x:{_,_,_}] := 
  Composition[Rotate3D[Y,b2],Rotate3D[Z,-b1]][x]
Rotate3D[Y,{b1_,b2_}][x:{_,_,_}] := 
  Composition[Rotate3D[Z,b1-Pi/2],Rotate3D[X,b2]][x]
Rotate3D[{b1_,b2_},Y][x:{_,_,_}] := 
  Composition[Rotate3D[X,-b2],Rotate3D[Z,Pi/2-b1]][x]
Rotate3D[Z,{b1_,b2_}][x:{_,_,_}] := 
  Composition[Rotate3D[Z,b1],Rotate3D[Y,Pi/2-b2]][x]
Rotate3D[{b1_,b2_},Z][x:{_,_,_}] := 
  Composition[Rotate3D[Y,b2-Pi/2],Rotate3D[Z,-b1]][x]

Rotate3D[X,a_][{x_,y_,z_}] := 
  {x,y Cos[a] - z Sin[a],y Sin[a] + z Cos[a]}
Rotate3D[Y,a_][{x_,y_,z_}] := 
  {z Sin[a] + x Cos[a],y,z Cos[a] - x Sin[a]}
Rotate3D[Z,a_][{x_,y_,z_}] := 
  {x Cos[a] - y Sin[a],x Sin[a] + y Cos[a],z}

Rotate3D[b:{_,_},a_][x:{_,_,_}] := 
  Composition[Rotate3D[X,b],Rotate3D[X,a],Rotate3D[b,X]][x]
Rotate3D[c:{_,_,_},b:{_,_},a_][x:{_,_,_}] := 
  Composition[Translate3D[c],Rotate3D[b,a],Translate3D[-c]][x]
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Reflect2D[X,Y]",
    FontWeight->"Bold"],
  "\nRiflessione del piano x,y che fissa l'origine e scambia tra loro i due \
versori canonici.\n",
  StyleBox["Reflect2D[X]  Reflect2D[Y]",
    FontWeight->"Bold"],
  "\nRiflessione del piano x,y che fissa l'origine e inverte il verso \
dell'asse coordinato indicato dal parametro.\n",
  StyleBox["Reflect2D[a]",
    FontWeight->"Bold"],
  "\nRiflessione del piano rispetto alla retta passante per l'origine e \
ortogonale alla direzione individuata dall'angolo a.\n",
  StyleBox["Reflect2D[c,a]",
    FontWeight->"Bold"],
  "\nRiflessione del piano rispetto alla retta passante per il punto c e \
ortogonale alla direzione individuata dall'angolo a."
}], "Text",
  AspectRatioFixed->True],

Cell["\<\
ClearAll[Reflect2D]

Reflect2D[X,Y][{x_,y_}] := {y,x}

Reflect2D[X][{x_,y_}] := {-x,y}
Reflect2D[Y][{x_,y_}] := {x,-y}

Reflect2D[a_][x:{_,_}] := 
  Composition[Rotate2D[a],Reflect2D[X],Rotate2D[-a]][x]
Reflect2D[c:{_,_},a_][x:{_,_}] := 
  Composition[Translate2D[c],Reflect2D[a],Translate2D[-c]][x]
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Reflect3D[X,Y]  Reflect3D[X,Z]  Reflect3D[Y,Z]",
    FontWeight->"Bold"],
  "\nRiflessione dello spazio x,y,z che fissa l'origine e scambia tra loro i \
due versori canonici indicati dai parametri.\n",
  StyleBox["Reflect3D[X]  Reflect3D[Y]  Reflect3D[Z]",
    FontWeight->"Bold"],
  "\nRiflessione dello spazio x,y,z che fissa l'origine e inverte il verso \
dell'asse coordinato indicato dal parametro.\n",
  StyleBox["Reflect3D[{b1,b2}]",
    FontWeight->"Bold"],
  "\nRiflessione dello spazio rispetto al piano passante per l'origine e \
ortogonale alla direzione individuata dalla coppia di angoli {b1,b2}.\n",
  StyleBox["Reflect3D[c,{b1,b2}]",
    FontWeight->"Bold"],
  "\nRiflessione dello spazio rispetto al piano passante per il punto c e \
ortogonale alla direzione individuata dalla coppia di angoli {b1,b2}."
}], "Text",
  AspectRatioFixed->True],

Cell[TextData[{
  "ClearAll[Reflect3D]\n\nReflect3D[X,Y][{x_,y_,z_}] := {y,x,z}\n\
Reflect3D[X,Z][{x_,y_,z_}] := {z,y,x}\nReflect3D[Y,Z][{x_,y_,z_}] := {x,z,y}\n\
\nReflect3D[X][{x_,y_,z_}] := {-x,y,z}\nReflect3D[Y][{x_,y_,z_}] := {x,-y,z}\n\
Reflect3D[Z][{x_,y_,z_}] := {x,y,-z}\n\nReflect3D[b:{_,_}][x:{_,_,_}] := \n  \
Composition[Rotate3D[X,b],Reflect3D[X],Rotate3D[b,X]][x]\n\
Reflect3D[c:{_,_,_},b:{_,_}][x:{_,_,_}] := \n  \
Composition[Translate3D[c],Reflect3D[b],Translate3D[-c]][x]",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 1]]
}], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Scale2D[f]  Scale2D[{fx,fy}]",
    FontWeight->"Bold"],
  "\nScalatura del piano x,y con centro l'origine e fattori f o {fx,fy} nelle \
due direzioni coordinate.\n",
  StyleBox["Scale2D[c,f]  Scale2D[c,{fx,fy}]",
    FontWeight->"Bold"],
  "\nScalatura del piano x,y con centro il punto c e fattori f o {fx,fy} \
nelle due direzioni coordinate."
}], "Text",
  AspectRatioFixed->True],

Cell["\<\
ClearAll[Scale2D]

Scale2D[f_][x:{_,_}] := f x
Scale2D[c:{_,_},f_][x:{_,_}] := 
  Composition[Translate[c],Scale2D[f],Translate[-c]][x]
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Scale3D[f]  Scale3D[{fx,fy,fz}]",
    FontWeight->"Bold"],
  "\nScalatura dello spazio x,y,z con centro l'origine e fattori f o \
{fx,fy,fy} nelle tre direzioni coordinate.\n",
  StyleBox["Scale3D[c,f]  Scale3D[c,{fx,fy,fz}]",
    FontWeight->"Bold"],
  "\nScalatura dello spazio x,y,z con centro il punto c e fattori f o \
{fx,fy,fz} nelle tre direzioni coordinate."
}], "Text",
  AspectRatioFixed->True],

Cell["\<\
ClearAll[Scale3D]

Scale3D[f_][x:{_,_,_}] := f x
Scale3D[c:{_,_,_},f_][x:{_,_,_}] := 
  Composition[Translate[c],Scale3D[f],Translate[-c]][x]
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Linear2D[m]",
    FontWeight->"Bold"],
  "\nTrasformazione lineare di R^2 data dalla moltiplicazione a destra dei \
vettori riga per la matrice m (scritta per righe).\n",
  StyleBox["Linear3D[m]",
    FontWeight->"Bold"],
  "\nTrasformazione lineare di R^3 data dalla moltiplicazione a destra dei \
vettori riga per la matrice m (scritta per righe).\n",
  StyleBox["Matrix2D[l]",
    FontWeight->"Bold"],
  "\nMatrice della trasformazione lineare l di R^2 rispetto alla base \
canonica (scritta per righe).\n",
  StyleBox["Matrix3D[l]",
    FontWeight->"Bold"],
  "\nMatrice della trasformazione lineare l di R^3 rispetto alla base \
canonica (scritta per righe)."
}], "Text",
  AspectRatioFixed->True],

Cell["\<\
ClearAll[Linear2D,Linear3D,Matrix2D,Matrix3D]

Linear2D[m_?MatrixQ][x:{_,_}] := x . m
Linear3D[m_?MatrixQ][x:{_,_,_}] := x . m

Matrix2D[l_] := Map[l,IdentityMatrix[2]]
Matrix3D[l_] := Map[l,IdentityMatrix[3]]

Matrix2D[Linear2D[m_]] := m
Matrix3D[Linear3D[m_]] := m
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Affine2D[m]",
    FontWeight->"Bold"],
  "\nTrasformazione affine del piano rappresentata dalla matrice estesa m \
rispetto alla base canonica (il vettore di traslazione e aggiunto come prima \
riga alla matrice della trasformazione lineare associata).\n",
  StyleBox["Affine3D[m]",
    FontWeight->"Bold"],
  "\nTrasformazione affine dello spazio rappresentata dalla matrice estesa m \
rispetto alla base canonica (il vettore di traslazione e aggiunto come prima \
riga alla matrice della trasformazione lineare associata).\n",
  StyleBox["ExtMatrix2D[t]",
    FontWeight->"Bold"],
  "\nMatrice estesa della trasformazione affine t del piano rispetto alla \
base canonica (il vettore di traslazione e aggiunto come prima riga alla \
matrice della trasformazione lineare associata).\n",
  StyleBox["ExtMatrix3D[t]",
    FontWeight->"Bold"],
  "\nMatrice estesa della trasformazione affine t dello spazio rispetto alla \
base canonica (il vettore di traslazione e aggiunto come prima riga alla \
matrice della trasformazione lineare associata)."
}], "Text",
  AspectRatioFixed->True],

Cell["\<\
ClearAll[Affine2D,Affine3D,ExtMatrix2D,ExtMatrix3D]

Affine2D[m_?MatrixQ][x:{_,_}] := First[m] + x . Rest[m]
Affine3D[m_?MatrixQ][x:{_,_,_}] := First[m] + x . Rest[m]

ExtMatrix2D[t_] := 
  Module[{v=t[{0,0}]},Prepend[Map[(t[#]-v)&,IdentityMatrix[2]],v]]
ExtMatrix3D[t_] := 
  Module[{v=t[{0,0,0}]},Prepend[Map[(t[#]-v)&,IdentityMatrix[3]],v]]

ExtMatrix2D[Affine2D[m_]] := m
ExtMatrix3D[Affine3D[m_]] := m
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ExtMatrixDot[m1,m2,...]",
    FontWeight->"Bold"],
  "\nMatrice estesa della trasformazione affine ottenuta componendo le \
trasformazioni affini con matrici estese m1,m2,...\n",
  StyleBox["ExtMatrixInverse[m]",
    FontWeight->"Bold"],
  "\nMatrice estesa della trasformazione affine inversa di quella data dalla \
matrice estesa m."
}], "Text"],

Cell[TextData[{
  "ClearAll[ExtMatrixDot,ExtMatrixInverse]\n\
SetAttributes[ExtMatrixDot,{Flat,OneIdentity}]\n\n\
ExtMatrixDot[m1_?MatrixQ,m2_?MatrixQ] :=\n  Prepend[Rest[m1] . \
Rest[m2],First[m1] . Rest[m2] + First[m2]]\n\n",
  StyleBox["ExtMatrixDot[m1_?MatrixQ] := m1\n\nExtMatrixInverse[m_?MatrixQ] \
:=\n  Map[Drop[#,1]&,Inverse[Transpose[Prepend[Transpose[m],{1,0,0,0}]]]]\n",
    FontFamily->"Courier"]
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["OmogTransf[t]",
    FontWeight->"Bold"],
  "\nTrasformazione omogenea associata alla trasformazione affine t, in \
qualunque dimensione > 1. \n",
  StyleBox["DeOmogTransf[t]",
    FontWeight->"Bold"],
  "\nTrasformazione affine associata alla trasformazione omogenea t, in \
qualunque dimensione > 1."
}], "Text",
  AspectRatioFixed->True],

Cell["\<\
ClearAll[OmogTransf,DeOmogTransf,CancelDenominators]

CancelDenominators[l_] := 
  Module[{fl = Together[l]},
    Cancel[Apply[PolynomialLCM,Map[Denominator,fl]] fl]]

OmogTransf[t_][ux:{_,_,__}]:=
  Module[{UX = Switch[Length[ux],3,{U,X,Y},4,{U,X,Y,Z}]},
    CancelDenominators[Omog[t[DeOmog[UX]]]] /. Thread[UX -> ux]]

DeOmogTransf[t_][x:{_,__}] := DeOmog[t[Omog[x]]]

OmogTransf[DeOmogTransf[t_]] := t
DeOmogTransf[OmogTransf[t_]] := t
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["OmogLinear2D[m]",
    FontWeight->"Bold"],
  "\nTrasformazione proiettiva del piano data dalla moltiplicazione a destra \
dei vettori riga omogenei, rispetto al riferimento proiettivo canonico, per \
la matrice omogenea m (scritta per righe).\n",
  StyleBox["OmogLinear3D[m]",
    FontWeight->"Bold"],
  "\nTrasformazione proiettiva dello spazio data dalla moltiplicazione a \
destra dei vettori riga omogenei, rispetto al riferimento proiettivo \
canonico, per la matrice omogenea m (scritta per righe).\n",
  StyleBox["OmogMatrix2D[t]",
    FontWeight->"Bold"],
  "\nMatrice omogenea della trasformazione proiettiva t del piano rispetto al \
riferimento proiettivo canonico (scritta per righe).\n",
  StyleBox["OmogMatrix3D[t]",
    FontWeight->"Bold"],
  "\nMatrice omogenea della trasformazione proiettiva t dello spazio rispetto \
al riferimento proiettivo canonico (scritta per righe)."
}], "Text",
  AspectRatioFixed->True],

Cell["\<\
ClearAll[OmogLinear2D,OmogLinear3D,OmogMatrix2D,OmogMatrix3D]

OmogLinear2D[m_?MatrixQ][ux:{_,_,_}] := ux . m
OmogLinear3D[m_?MatrixQ][ux:{_,_,_,_}] := ux . m

OmogMatrix2D[t_] := Map[t,IdentityMatrix[3]]
OmogMatrix3D[t_] := Map[t,IdentityMatrix[4]]

OmogMatrix2D[OmogLinear2D[m_]] := m
OmogMatrix3D[OmogLinear3D[m_]] := m
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{552, 706},
WindowMargins->{{Automatic, 284}, {Automatic, -1}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000ad2<?oYonl3<`920dL5N`?P0080001804P000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 37, 0, 36, "Subsubtitle"],
Cell[1757, 51, 295, 9, 80, "Text"],
Cell[2055, 62, 197, 8, 71, "Input",
  InitializationCell->True],
Cell[2255, 72, 511, 12, 125, "Text"],
Cell[2769, 86, 328, 12, 123, "Input",
  InitializationCell->True],
Cell[3100, 100, 1520, 31, 365, "Text"],
Cell[4623, 133, 1379, 40, 487, "Input",
  InitializationCell->True],
Cell[6005, 175, 760, 18, 200, "Text"],
Cell[6768, 195, 379, 15, 162, "Input",
  InitializationCell->True],
Cell[7150, 212, 887, 18, 200, "Text"],
Cell[8040, 232, 610, 12, 201, "Input",
  InitializationCell->True],
Cell[8653, 246, 411, 10, 110, "Text"],
Cell[9067, 258, 215, 9, 84, "Input",
  InitializationCell->True],
Cell[9285, 269, 433, 10, 110, "Text"],
Cell[9721, 281, 221, 9, 84, "Input",
  InitializationCell->True],
Cell[9945, 292, 730, 18, 200, "Text"],
Cell[10678, 312, 346, 14, 149, "Input",
  InitializationCell->True],
Cell[11027, 328, 1110, 22, 260, "Text"],
Cell[12140, 352, 486, 16, 175, "Input",
  InitializationCell->True],
Cell[12629, 370, 375, 9, 110, "Text"],
Cell[13007, 381, 451, 9, 149, "Input",
  InitializationCell->True],
Cell[13461, 392, 367, 10, 110, "Text"],
Cell[13831, 404, 519, 18, 201, "Input",
  InitializationCell->True],
Cell[14353, 424, 958, 20, 230, "Text"],
Cell[15314, 446, 402, 14, 149, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

