(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     19939,        504]*)
(*NotebookOutlinePosition[     45782,       1449]*)
(*  CellTagsIndexPosition[     45738,       1445]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Visualizzazione", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["Show[obj]",
    FontWeight->"Bold"],
  "\nVisualizza l'oggetto obj convertendolo in un oggetto grafico di sistema \
e utilizzando la funzione di visualizzazione Show di sistema.\n",
  StyleBox["Show[obj,opts]",
    FontWeight->"Bold"],
  "\nVisualizza l'oggetto obj con le opzioni di sistema opts.\n",
  StyleBox["Show[group,opts]  Show[shape,opts]\n",
    FontWeight->"Bold"],
  "Visualizza l'oggetto ottenuto espandendo l'albero generato da un nodo. "
}], "Text",
  AspectRatioFixed->True],

Cell["\<\
Unprotect[Show]; Clear[Show]

Show[obj_Object,opts___?OptionQ] :=
  (Switch[Dim[obj],
     1, Show[Graphics[ShowExpand[obj] /.
              {Point[x_] :> Point[{x,0}],
               (p:Line|Polygon)[x_] :> p[Map[{#,0}&,x]]}],
          opts,Axes -> False,Frame -> True,
          FrameTicks -> {Vertices[obj],{},{},{}},
          PlotRange -> {All,{0,0}},AspectRatio -> .1],
     2, Show[Graphics[ShowExpand[obj]],
          opts,Axes -> False,Frame -> True,
          PlotRange->All,AspectRatio -> Automatic],
     3, Show[Graphics3D[ShowExpand[obj]],
          opts,PlotRange->All,Boxed->False]]; obj)

Show[n_?NodeQ,opts___?OptionQ] :=
  Show[NodeExpand[n],opts]

Protect[Show];
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ShowExpand[obj]",
    FontWeight->"Bold"],
  "\nEspande l'oggetto obj come lista di primitive e direttive grafiche di \
sistema per consentirne la visualizzazione come oggetto grafico di sistema. \
Tiene conto della eventuale specificazione dei colori dei vertici in modo \
piatto (colore medio uniforme su ciascuna primitiva Line o Polygon). "
}], "Text"],

Cell["\<\
ClearAll[ShowExpand];

ShowExpand[obj_Object] :=
  ShowExpand[Structure[ObjectExpand[obj]],Vertices[obj],Colors[obj],
             {4,RGBColor[0,0,0],1,RGBColor[0,0,0],RGBColor[1,1,1],
              RGBColor[1,1,1],RGBColor[0,0,0],1,{True,True}},Dim[obj]]
              
ShowExpand[l_List,v_List,col_Colors,att_List,dim_] :=
  Module[{a = att,i},
    Replace[l,
      {Polygon[x_] :> 
         {If[a[[9,2]],
              {If[FreeQ[i = col[[1]][[x]],0],
                  Apply[RGBColor,Apply[Mean,col[[2]][[i]]]],a[[5]]],
               If[dim == 3,
                  Apply[Sequence,{Apply[SurfaceColor,a[[{6,7,8}]]],
                    If[Not[a[[9,1]]],EdgeForm[],
                       EdgeForm[AbsoluteThickness[a[[3]]],a[[4]]]]}],
                  Nothing],
               Polygon[v[[x]]]},Nothing],
           If[a[[9,1]] && (dim < 3 || Not[a[[9,2]]]),
              {AbsoluteThickness[a[[3]]],a[[4]],
               Line[v[[Append[x,First[x]]]]]},Nothing]},
       Line[x_] :> 
         {AbsoluteThickness[a[[3]]],
          If[FreeQ[i = col[[1]][[x]],0],
             Apply[RGBColor,Apply[Mean,col[[2]][[i]]]],a[[4]]],
          Line[v[[x]]]},
       Point[x_] :> 
         {AbsolutePointSize[a[[1]]],
          If[(i = col[[1]][[x]]) > 0,
             Apply[RGBColor,col[[2]][[i]]],a[[2]]],
          Point[v[[x]]]},
       x_List :> ShowExpand[x,v,col,a,dim],
       PointSize[s_] :> (a[[1]] = s;Nothing),
       PointColor[rgb__] :> (a[[2]] = RGBColor[rgb];Nothing),
       LineWidth[w_] :> (a[[3]] = w;Nothing),
       LineColor[rgb__] :> (a[[4]] = RGBColor[rgb];Nothing),
       FillColor[rgb__] :> (a[[5]] = RGBColor[rgb];Nothing),
       EmissiveColor[__] :> Nothing,
       AmbientColor[__] :> Nothing,
       DiffuseColor[rgb__] :> (a[[6]] = RGBColor[rgb];Nothing),
       SpecularColor[rgb__] :> (a[[7]] = RGBColor[rgb];Nothing),
       Shininess[s_] :> (a[[8]] = s;Nothing),
       PolygonMode[m__] :> 
         (a[[9,1]] = Not[FreeQ[{m},Line]];
          a[[9,2]] = Not[FreeQ[{m},Fill]];Nothing)},1]]
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["AmbientLight[i]  AmbientLight[r,g,b]",
    FontWeight->"Bold"],
  "\nLuce ambiente bianca di intensita' i o colorata con componenti r,g,b.",
  StyleBox["\nDirectionalLight[v,i]  DirectionalLight[v,r,g,b]",
    FontWeight->"Bold"],
  "\nLuce direzionale con direzione v, bianca di intensita' i o colorata con \
componenti r,g,b.",
  StyleBox["\nPointLight[p,i]  PointLight[p,r,g,b]",
    FontWeight->"Bold"],
  "\nLuce puntiforme posta nel punto p, bianca di intensita' i o colorata con \
componenti r,g,b.",
  StyleBox["\nSpotLight[p,v,i]  SpotLight[p,v,r,g,b,a,e]\n",
    FontWeight->"Bold"],
  "Luce spot posta nel punto p con direzione v, bianca di intensita' i o \
colorata con componenti r,g,b, angolo di apertura a ed espontente e.\nSe non \
indicati a ed e si assumono uguali a Pi/4 e 1."
}], "Text"],

Cell[TextData[{
  "Unprotect[AmbientLight];\n\
ClearAll[AmbientLight,DirectionalLight,PointLight,SpotLight]\n\n\
AmbientLight[i_:1] := AmbientLight[i,i,i]\n\nDirectionalLight[v_,i_:1] := \
DirectionalLight[v,i,i,i]\n\nPointLight[p_,i_:1] := PointLight[p,i,i,i]\n\n\
SpotLight[p_,v_,i_:1] := SpotLight[p,v,i,i,i]",
  StyleBox["\n",
    FontWeight->"Bold"],
  "SpotLight[p_,v_,r_,g_,b_,a_:Pi/4] := SpotLight[p,v,r,g,b,a,1]\n\n\
Protect[AmbientLight];\n"
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["View[obj]",
    FontWeight->"Bold"],
  "\nVisualizza l'oggetto obj utilizzando la funzione di visualizzazione Show \
di sistema senza illuminazione, dopo aver effettuato il calcolo dei colori \
delle facce in base alle luci specificate e agli attibuti dell'oggetto.\n",
  StyleBox["View[obj,lights]",
    FontWeight->"Bold"],
  "\nVisualizza l'oggetto obj utilizzando la funzione di visualizzazione Show \
di sistema senza illuminazione, dopo aver effettuato il calcolo dei colori \
delle facce in base alle luci specificate e agli attibuti dell'oggetto.\n",
  StyleBox["View[obj,lights,opts]",
    FontWeight->"Bold"],
  "\nVisualizza l'oggetto obj con le opzioni di visualizzazione e di sistema \
opts.\n",
  StyleBox["View[group,lights,opts]  Show[shape,lights,opts]\n",
    FontWeight->"Bold"],
  "Visualizza l'oggetto ottenuto espandendo l'albero generato da un nodo.\n",
  StyleBox["ViewCenter -> {cx,cy,cz}",
    FontWeight->"Bold"],
  "\nOpzione di View che definisce il centro di vista.\n",
  StyleBox["ViewClipping -> front  ViewClipping -> {front,back}",
    FontWeight->"Bold"],
  "\nOpzione di View che definisce le distanze di clipping.\n",
  StyleBox["ViewPoint -> {x,y,z}",
    FontWeight->"Bold"],
  "\nOpzione di View che definisce il punto di vista.\n",
  StyleBox["ViewPlane -> XY|XZ|YZ|{v1,v2}",
    FontWeight->"Bold"],
  "\nOpzione di View che definisce la giacitura del piano di vista.\n",
  StyleBox["ViewProjection -> Parallel|Perspective",
    FontWeight->"Bold"],
  "\nOpzione di View che definisce il tipo di proiezione.\n",
  StyleBox["ViewVertical -> {vx,vy,vz}",
    FontWeight->"Bold"],
  "\nOpzione di View che definisce la verticale della vista.\n",
  StyleBox["ViewWindow -> width  ViewWindow -> {width,height}",
    FontWeight->"Bold"],
  "\nOpzione di View che definisce le dimensioni della finestra di vista."
}], "Text"],

Cell["\<\
ClearAll[View]

Options[View] = {ViewCenter -> {0.,0.,0.},ViewClipping -> Automatic,
                 ViewDepthFactor -> 1,ViewPlane -> Automatic,
                 ViewPoint -> {1.,0.,0.},ViewProjection -> Perspective,
                 ViewVertical -> {0.,0.,1.},ViewWindow -> Automatic};

View[obj_Object,l_:{},opts___?OptionQ] :=
  Module[{lights = If[OptionQ[l] && l =!= {},{},l],
          op = Flatten[{If[OptionQ[l] && l =!= {},l,Nothing],
                        opts,Options[View]}],
          ob = ObjectExpand[If[Dim[obj] == 3,obj,
                 MatrixTransform[{{1,0,0},{0,1,0}},obj]]]},
    Module[{vc = ViewCenter /. op,
            vcl = Flatten[{ViewClipping /. op}],
            vdf = ViewDepthFactor /. op,vpl = ViewPlane /. op,
            vp = ViewPoint /. op,vpr = ViewProjection /. op,
            vv = ViewVertical /. op,
            vw = Flatten[{ViewWindow /. op}],
            fclip,bclip,hclip,vclip,vdir,vmat},
      fclip = If[vcl === {Automatic},1,vcl[[1]]];
      bclip = If[Length[vcl] < 2,Infinity,vcl[[2]]];
      hclip = If[vw === {Automatic},All,vw[[1]] {-1,1}];
      vclip = If[Length[vw] < 2,hclip,vw[[2]] {-1,1}];
      vdir = Versor[vc - vp];
      vmat = ViewMatrix[vp,vdir,vv,vpl,vdf]; 
      ob = LinearClip[ob,-vdir,-vdir . vp - fclip,
                      Expand -> False,Normalize -> False];
      If[bclip < Infinity,
         ob = LinearClip[ob,vdir,vdir . vp + bclip,
                         Expand -> False,Normalize -> False]]; 
      ob = ViewExpand[ob,lights,vp,vdir,vpr === Parallel];
      ob = ExtMatrixTransform[vmat,ob];
      ob = OmogMatrixTransform[ProjectionMatrix[vpr],ob];
      Module[{gr = Structure[ob] /.
                     (p:Point|Line|Polygon)[x_] :> 
                                      p[Vertices[ob][[x]]]},
        Show[Graphics3D[gr,
               Join[{Plot3Matrix -> IdentityMatrix[4] {1,1,-1,1},
                     PlotRange -> {hclip,vclip,All},Lighting -> False},
                     Select[op,FreeQ[#,ViewClipping|ViewDepthFactor|
                                       ViewPlane|ViewProjection|
                                       ViewWindow]&],
                     {Boxed -> True,Axes -> {True,True,False}}]]];obj]]]

View[n_?NodeQ,r___] := View[NodeExpand[n],r]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["ViewExpand[obj,lights,vp,vd,par]",
    FontWeight->"Bold"],
  "\nEspande l'oggetto obj come lista di primitive e direttive grafiche di \
sistema effettuando il calcolo dei colori delle facce in base alle luci, al \
punto di vista vp, alla direzione di vista vd, al tipo di proiezione (par \
\[EGrave] un parametro booleano vero/falso a seconda che la proiezione sia \
parallela/prospettica) e agli attributi dell'oggetto, per consentirne la \
visualizzazione come oggetto grafico di sistema."
}], "Text"],

Cell["\<\
ClearAll[ViewExpand];

ViewExpand[obj_Object,lights_,vp_,vd_,par_,opts___?OptionsQ] :=
  Module[{nl = N[Flatten[{lights}] /.
           {d_DirectionalLight :> MapAt[Versor,d,1],
            s_SpotLight :> MapAt[Versor,s,2]}]},
     Object[ViewExpand[Structure[obj],
              Vertices[obj],Colors[obj],Normals[obj],
              {1,{0,0,0},1,{0,0,0},{1,1,1},{0,0,0},{0,0,0},
               {1,1,1},{0,0,0},1,{True,True},{True,False}},
              nl,vp,vd,par],Vertices[obj]]]

ViewExpand[l_List,v_,col_,nor_,att_,lights_,vp_,vd_,par_] := 
  Module[{a = att,i},
    Replace[l,
      {Polygon[x_] :> 
         If[a[[11,2]],
            {If[FreeQ[i = col[[1]][[x]],0],
                Apply[RGBColor,Apply[Mean,col[[2]][[i]]]],
                If[lights == {},Apply[RGBColor,a[[5]]],
                   ColorExpand[Apply[Mean,v[[x]]],
                     If[FreeQ[i = nor[[1]][[x]],0],
                        Versor[Apply[Mean,nor[[2]][[i]]]],
                        Versor[NormalVector[Polygon[v[[x]]]]]],
                     a[[{6,7,8,9,10}]],a[[12]],lights,vp,vd,par]]],
                If[Not[a[[11,1]]],EdgeForm[],
                   EdgeForm[AbsoluteThickness[a[[3]]],
                            Apply[RGBColor,a[[4]]]]],
                Polygon[x]},
             If[a[[11,1]],
                {AbsoluteThickness[a[[3]]],Apply[RGBColor,a[[4]]],
                Line[Append[x,First[x]]]},Nothing]],
       Line[x_] :> 
         {AbsoluteThickness[a[[3]]],
          If[FreeQ[i = col[[1]][[x]],0],
             Apply[RGBColor,Apply[Mean,col[[2]][[i]]]],
             Apply[RGBColor,a[[4]]]],
          Line[x]},
       Point[x_] :> 
         {AbsolutePointSize[a[[1]]],
          If[(i = col[[1]][[x]]) > 0,
             Apply[RGBColor,col[[2]][[i]]],
             Apply[RGBColor,a[[2]]]],
          Point[x]},
       x_List :> ViewExpand[x,v,col,nor,a,lights,vp,vd,par],
       PointSize[s_] :> (a[[1]] = s;Nothing),
       PointColor[rgb__] :> (a[[2]] = {rgb};Nothing),
       LineWidth[w_] :> (a[[3]] = w;Nothing),
       LineColor[rgb__] :> (a[[4]] = {rgb};Nothing),
       FillColor[rgb__] :> (a[[5]] = {rgb};Nothing),
       EmissiveColor[rgb__] :> (a[[6]] = {rgb};Nothing),
       AmbientColor[rgb__] :> (a[[7]] = {rgb};Nothing),
       DiffuseColor[rgb__] :> (a[[8]] = {rgb};Nothing),
       SpecularColor[rgb__] :> (a[[9]] = {rgb};Nothing),
       Shininess[s_] :> (a[[10]] = s;Nothing),
       PolygonMode[m__] :> 
         (a[[11,1]] = Not[FreeQ[{m},Line]];
          a[[11,2]] = Not[FreeQ[{m},Fill]];Nothing),
       FaceMode[m__] :> 
         (a[[12,1]] = Not[FreeQ[{m},Front]];
          a[[12,2]] = Not[FreeQ[{m},Back]];Nothing)},1]]
\
\>", "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ColorExpand[x,n,col,fm,lights,vp,vd,par]",
    FontWeight->"Bold"],
  "\nCalcola il colore di una faccia nel punto x con normale n e attributi \
col e fm in base alla lista di luci lights e ai parametri di vista."
}], "Text"],

Cell[TextData[{
  "ClearAll[ColorExpand,AttenuationFactor,FaceFlag]\n\n\
ColorExpand[x_,n_,col_,fm_,l_List,vp_,vd_,par_] :=\n  Module[{w = \
If[par,-vd,Versor[vp - x]],nw,c},\n    If[FaceFlag[nw = n . w,fm],\n       c \
= Append[Map[ColorExpand[x,n,col,w,nw,fm,#]&,l],col[[1]]];\n         \
Apply[RGBColor,Map[Min[1,#]&,Apply[Plus,c]]],\n       RGBColor[0,0,0]]]\n\n\
ColorExpand[_,_,col_,__,AmbientLight[r_,g_,b_]] := col[[2]] {r,g,b}\n  \n\
ColorExpand[x_,n_,col_,w_,nw_,fm_,DirectionalLight[v_,r_,g_,b_]] := ",
  StyleBox["\n",
    FontColor->RGBColor[0, 0, 1]],
  "  Module[{nv = n . v,rw},  \n    If[FaceFlag[- nv,fm],\n       rw = (v - 2 \
nv n) . w;\n         Max[-nv Sign[nw],0] *\n           (col[[3]] + col[[4]] \
Max[rw,0]^col[[5]]) {r,g,b},\n       {0,0,0}]]\n\n\
ColorExpand[x_,n_,col_,w_,nw_,fm_,PointLight[p_,r_,g_,b_]] := \n  Module[{v = \
p - x,vv,nv,rw,f},\n    If[FaceFlag[nv = n .(vv = Versor[v]),fm],\n       f = \
AttenuationFactor[Norm[v]];\n         rw = (2 nv n - vv) . w;\n         f \
Max[nv Sign[nw],0] * \n           (col[[3]] + col[[4]] Max[rw,0]^col[[5]]) \
{r,g,b},\n       {0,0,0}]]\n\n\
ColorExpand[x_,n_,col_,w_,nw_,fm_,SpotLight[p_,vl_,r_,g_,b_,a_,e_]] := \n  \
Module[{v = p - x,vv,nv,rw,f,vvl,fl},\n    If[FaceFlag[nv = n .(vv = \
Versor[v]),fm],\n       f = AttenuationFactor[Norm[v]];\n         rw = (2 nv \
n - vv) . w;\n         vvl = vv . vl;\n         fl = If[-vvl > \
Cos[a],-vvl,0]^e;\n         f fl Max[nv Sign[nw],0] * \n           (col[[3]] \
+ col[[4]] Max[rw,0]^col[[5]]) {r,g,b},\n       {0,0,0}]]\n\n\
FaceFlag[nv_,fm_] := If[nv > 0,fm[[1]],fm[[2]]]\n\nAttenuationFactor = \
Compile[d,1/(1 + d/2 + d^2/4)];\n"
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["ViewMatrix[vp,vd,vv,{v1,v2},vdf]",
    FontWeight->"Bold"],
  "\nMatrice della trasformazione di vista con punto di vista vp, direzione \
di vista vd, verticale di vista vv, giacitura del piano di vista generata da \
v1 e v2, fattore di profondita' vfd.\n",
  StyleBox["ProjectionMatrix[Parallel]  ProjectionMatrix[Perspective]",
    FontWeight->"Bold"],
  "\nMatrici di proiezione standard per la vista parallela e per la vista \
prospettica.\n",
  StyleBox["OmogMatrixTransform[m,obj]",
    FontWeight->"Bold"],
  "\nTrasformato dell'oggetto obj mediante la matrice omogenea m."
}], "Text"],

Cell["\<\
ClearAll[ViewMatrix,ProjectionMatrix,OmogMatrixTransform]

ViewMatrix[vp_,vd_,vv_,vpl_,vdf_] :=
  Module[{vz = N[Switch[vpl,XY,{0,0,1},YZ,{1,0,0},XZ,{0,-1,0},
                        Automatic,-vd,_,Versor[Apply[Cross,vpl]]]]},
    Module[{vx = N[Cross[vv,vz]],nvd = vdf vd/(vd . vz)},
      Module[{vy = Cross[vz,vx]},
        ExtMatrixDot[ExtMatrixInverse[{vp,vx,vy,vz}],
                     ExtMatrixInverse[{{0,0,0},{1,0,0},{0,1,0},
                                       {vx . nvd,vy . nvd,1}}]]]]]

ProjectionMatrix[proj_] :=
  Switch[proj,Parallel,IdentityMatrix[4],
              Perspective,{{0,0,0,1},{0,1,0,0},{0,0,1,0},{-1,0,0,-1}}]
              
OmogMatrixTransform[m_?MatrixQ,obj_Object] :=
  Object[Structure[obj],DeOmogList[OmogList[Vertices[obj]] . m]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["NormalVector[Polygon[{x,...}]]",
    FontWeight->"Bold"],
  "\nVettore normale al poligono Polygon[x,...].\n",
  StyleBox["ToTriangles[Polygon[{x,...}]]",
    FontWeight->"Bold"],
  "\nTriangolazione del poligono Polygon[x,...] mediante una lista di \
primitive Polygon con tre vertici ciascuna."
}], "Text"],

Cell["\<\
NormalVector[Polygon[x_List]] :=
  Sum[Cross[x[[i]] - x[[1]],x[[i+1]] - x[[1]]],{i,2,Length[x]-1}]

ToTriangles[Polygon[x_List]] :=
  Table[Polygon[x[[{1,i,i+1}]]],{i,2,Length[x]-1}]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["PolygonToLine[obj]",
    FontWeight->"Bold"],
  "\nSostituisce ogni primitiva Polygon in obj con una Line che realizza il \
bordo del poligono.\n",
  StyleBox["AddPointLabels[obj]",
    FontWeight->"Bold"],
  "\nAggiunge all'oggetto obj etichette con gli indici dei vertici.\n",
  StyleBox["RemoveLabels[obj]",
    FontWeight->"Bold"],
  "\nRimuove le etichette dall'oggetto obj."
}], "Text"],

Cell["\<\
ClearAll[PolygonToLine,AddPointLabels]

PolygonToLine[obj_] := obj /. Polygon[{x_,y___}] :> Line[{x,y,x}]

AddPointLabels[Object[s_,v_,cn___]] := 
  Object[
    {s,Table[Text[ToString[i],v[[i]],{-1,-1}],{i,Length[v]}]},v,cn] 
  \
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["WhiteLights",
    FontWeight->"Bold"],
  "\nLuci bianche in posizione standard rispetto alla piattaforma di vista di \
sistema.\n",
  StyleBox["DefaultLights",
    FontWeight->"Bold"],
  "\nLuci colorate standard rispetto alla piattaforma di vista di sistema."
}], "Text"],

Cell["\<\
WhiteLights = {{{1.,0.,1.},RGBColor[0.8,0.8,0.8]},
               {{1.,1.,1.},RGBColor[0.5,0.5,0.5]},
               {{0.,1.,1.},RGBColor[0.2,0.2,0.2]}};

DefaultLights = {{{1.,0.,1.},RGBColor[1.,0.,0.]},
                 {{1.,1.,1.},RGBColor[0.,1.,0.]},
                 {{0.,1.,1.},RGBColor[0.,0.,1.]}};
\
\>", "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{557, 713},
WindowMargins->{{Automatic, 162}, {2, Automatic}},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000ad2<?oYonl3<`920dL5N`?P0080001804P000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 250, 9, 36, "Subsubtitle",
  Evaluatable->False],
Cell[1970, 60, 519, 12, 125, "Text"],
Cell[2492, 74, 763, 24, 279, "Input",
  InitializationCell->True],
Cell[3258, 100, 384, 7, 110, "Text"],
Cell[3645, 109, 2103, 51, 630, "Input",
  InitializationCell->True],
Cell[5751, 162, 835, 17, 200, "Text"],
Cell[6589, 181, 492, 11, 188, "Input",
  InitializationCell->True],
Cell[7084, 194, 1888, 39, 455, "Text"],
Cell[8975, 235, 2317, 49, 617, "Input",
  InitializationCell->True],
Cell[11295, 286, 532, 9, 125, "Text"],
Cell[11830, 297, 2742, 65, 812, "Input",
  InitializationCell->True],
Cell[14575, 364, 253, 5, 65, "Text"],
Cell[14831, 371, 1703, 27, 565, "Input",
  InitializationCell->True],
Cell[16537, 400, 620, 13, 155, "Text"],
Cell[17160, 415, 825, 20, 240, "Input",
  InitializationCell->True],
Cell[17988, 437, 336, 8, 95, "Text"],
Cell[18327, 447, 236, 8, 84, "Input",
  InitializationCell->True],
Cell[18566, 457, 420, 11, 125, "Text"],
Cell[18989, 470, 281, 10, 110, "Input",
  InitializationCell->True],
Cell[19273, 482, 300, 8, 95, "Text"],
Cell[19576, 492, 359, 10, 110, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

